@@ -21,9 +21,9 @@
 	    0
 	    (if (= mn 0)
 		1
-		(let* ((mx (max k (- n k)))
-		       (cnk (+ 1 mx)))
-		  (do ((i 2 (+ 1 i)))
+		(let ((mx (max k (- n k))))
+		  (do ((cnk (+ 1 mx))
+		       (i 2 (+ 1 i)))
 		      ((> i mn) cnk)
 		    (set! cnk (/ (* cnk (+ mx i)) i))))))))))
 
@@ -37,11 +37,11 @@
 (define src-duration
   (let ((documentation "(src-duration envelope) returns the new duration of a sound after using 'envelope' for time-varying sampling-rate conversion"))
     (lambda (e)
-      (let* ((len (length e))
-	     (all-x (- (e (- len 2)) (e 0))) ; last x - first x
-	     (dur 0.0))
-	(do ((i 0 (+ i 2)))
-	    ((>= i (- len 2)) dur)
+      (let ((len (- (length e) 2)))
+	(do ((all-x (- (e len) (e 0))) ; last x - first x
+	     (dur 0.0)
+	     (i 0 (+ i 2)))
+	    ((>= i len) dur)
 	  (let ((area (let ((x0 (e i))
 			    (x1 (e (+ i 2)))
 			    (y0 (e (+ i 1))) ; 1/x x points
@@ -113,14 +113,14 @@
 	;; now take the DFT
 	(let ((pk 0.0)
 	      (w (make-vector N)))
-	  (do ((i 0 (+ i 1)))
+	  (do ((i 0 (+ i 1))
+	       (sum 0.0 0.0))
 	      ((= i N))
-	    (let ((sum 0.0))
-	      (do ((k 0 (+ k 1)))
-		  ((= k N))
-		(set! sum (+ sum (* (vals k) (exp (/ (* 2.0 0+1.0i pi k i) N))))))
-	      (set! (w i) (magnitude sum))
-	      (set! pk (max pk (w i)))))
+	    (do ((k 0 (+ k 1)))
+		((= k N))
+	      (set! sum (+ sum (* (vals k) (exp (/ (* 2.0 0+1.0i pi k i) N))))))
+	    (set! (w i) (magnitude sum))
+	    (set! pk (max pk (w i))))
 	  ;; scale to 1.0 (it's usually pretty close already, that is pk is close to 1.0)
 	  (do ((i 0 (+ i 1)))
 	      ((= i N))
@@ -535,7 +535,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 	    (am (* 0.5 (+ order 1)))
 	    (q (/ (* pi 2.0) order)))
 	(if (not (float-vector? spectr))
-	    (error "spectrum->coeffs spectrum argument should be a float-vector"))
+	    (error 'wrong-type-arg "spectrum->coeffs spectrum argument should be a float-vector: ~A" spectr))
 	(do ((j 0 (+ j 1))
 	     (jj (- order 1) (- jj 1)))
 	    ((= j m) coeffs)
@@ -574,23 +574,23 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
   (let ((documentation "(make-hilbert-transform (len 30)) makes a Hilbert transform filter"))
     (lambda* ((len 30))
       (let ((arrlen (+ 1 (* 2 len))))
-	(let ((arr (make-float-vector arrlen))
-	      (lim (if (even? len) len (+ 1 len))))
-	  (do ((i (- len) (+ i 1)))
-	      ((= i lim))
-	    (let ((k (+ i len))
-		  (denom (* pi i))
-		  (num (- 1.0 (cos (* pi i)))))
-	      (set! (arr k)
-		    (if (or (= num 0.0) 
-			    (= i 0))
-			0.0
-			;; this is the "ideal" -- rectangular window -- version:
-			;; (set! (arr k) (/ num denom))
-			;; this is the Hamming window version:
-			(* (/ num denom) 
-			   (+ .54 (* .46 (cos (/ (* i pi) len))))))))) ; window
-	  (make-fir-filter arrlen arr))))))
+	(do ((arr (make-float-vector arrlen))
+	     (lim (if (even? len) len (+ 1 len)))
+	     (i (- len) (+ i 1)))
+	    ((= i lim)
+	     (make-fir-filter arrlen arr))
+	  (let ((k (+ i len))
+		(denom (* pi i))
+		(num (- 1.0 (cos (* pi i)))))
+	    (set! (arr k)
+		  (if (or (= num 0.0) 
+			  (= i 0))
+		      0.0
+		      ;; this is the "ideal" -- rectangular window -- version:
+		      ;; (set! (arr k) (/ num denom))
+		      ;; this is the Hamming window version:
+		      (* (/ num denom) 
+			 (+ .54 (* .46 (cos (/ (* i pi) len))))))))))))) ; window
 
 (define hilbert-transform fir-filter)
 
@@ -644,10 +644,11 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 (define make-highpass
   (let ((documentation "(make-highpass fc (len 30)) makes an FIR highpass filter"))
     (lambda* (fc (len 30))
-      (let* ((arrlen (+ 1 (* 2 len)))
-	     (arr (make-float-vector arrlen)))
-	(do ((i (- len) (+ i 1)))
-	    ((= i len))
+      (let ((arrlen (+ 1 (* 2 len))))
+	(do ((arr (make-float-vector arrlen))
+	     (i (- len) (+ i 1)))
+	    ((= i len)
+	     (make-fir-filter arrlen arr))
 	  (let ((k (+ i len))
 		(denom (* pi i))
 		(num (- (sin (* fc i)))))
@@ -655,8 +656,8 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 		  (if (= i 0)
 		      (- 1.0 (/ fc pi))
 		      (* (/ num denom) 
-			 (+ .54 (* .46 (cos (/ (* i pi) len)))))))))
-	(make-fir-filter arrlen arr)))))
+			 (+ .54 (* .46 (cos (/ (* i pi) len)))))))))))))
+	
 
 (define highpass fir-filter)
 
@@ -672,10 +673,11 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 (define make-lowpass
   (let ((documentation "(make-lowpass fc (len 30)) makes an FIR lowpass filter"))
     (lambda* (fc (len 30))
-      (let* ((arrlen (+ 1 (* 2 len)))
-	     (arr (make-float-vector arrlen)))
-	(do ((i (- len) (+ i 1)))
-	    ((= i len))
+      (let ((arrlen (+ 1 (* 2 len))))
+	(do ((arr (make-float-vector arrlen))
+	     (i (- len) (+ i 1)))
+	    ((= i len)
+	     (make-fir-filter arrlen arr))
 	  (let ((k (+ i len))
 		(denom (* pi i))
 		(num (sin (* fc i))))
@@ -683,8 +685,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 		  (if (= i 0)
 		      (/ fc pi)
 		      (* (/ num denom) 
-			 (+ .54 (* .46 (cos (/ (* i pi) len)))))))))
-	(make-fir-filter arrlen arr)))))
+			 (+ .54 (* .46 (cos (/ (* i pi) len)))))))))))))
 
 (define lowpass fir-filter)
 
@@ -699,10 +700,11 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 (define make-bandpass
   (let ((documentation "(make-bandpass flo fhi (len 30)) makes an FIR bandpass filter"))
     (lambda* (flo fhi (len 30))
-      (let* ((arrlen (+ 1 (* 2 len)))
-	     (arr (make-float-vector arrlen)))
-	(do ((i (- len) (+ i 1)))
-	    ((= i len))
+      (let ((arrlen (+ 1 (* 2 len))))
+	(do ((arr (make-float-vector arrlen))
+	     (i (- len) (+ i 1)))
+	    ((= i len)
+	     (make-fir-filter arrlen arr))     
 	  (let ((k (+ i len))
 		(denom (* pi i))
 		(num (- (sin (* fhi i)) (sin (* flo i)))))
@@ -710,8 +712,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 		  (if (= i 0)
 		      (/ (- fhi flo) pi)
 		      (* (/ num denom) 
-			 (+ .54 (* .46 (cos (/ (* i pi) len)))))))))
-	(make-fir-filter arrlen arr)))))
+			 (+ .54 (* .46 (cos (/ (* i pi) len)))))))))))))
 
 (define bandpass fir-filter)
 
@@ -741,10 +742,11 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 (define make-bandstop
   (let ((documentation "(make-bandstop flo fhi (len 30)) makes an FIR bandstop (notch) filter"))
     (lambda* (flo fhi (len 30))
-      (let* ((arrlen (+ 1 (* 2 len)))
-	     (arr (make-float-vector arrlen)))
-	(do ((i (- len) (+ i 1)))
-	    ((= i len))
+      (let ((arrlen (+ 1 (* 2 len))))
+	(do ((arr (make-float-vector arrlen))
+	     (i (- len) (+ i 1)))
+	    ((= i len)
+	     (make-fir-filter arrlen arr))     
 	  (let ((k (+ i len))
 		(denom (* pi i))
 		(num (- (sin (* flo i)) (sin (* fhi i)))))
@@ -752,8 +754,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 		  (if (= i 0)
 		      (- 1.0 (/ (- fhi flo) pi))
 		      (* (/ num denom) 
-			 (+ .54 (* .46 (cos (/ (* i pi) len)))))))))
-	(make-fir-filter arrlen arr)))))
+			 (+ .54 (* .46 (cos (/ (* i pi) len)))))))))))))
 
 (define bandstop fir-filter)
 
@@ -768,18 +769,18 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 (define make-differentiator
   (let ((documentation "(make-differentiator (len 30)) makes an FIR differentiator (highpass) filter"))
     (lambda* ((len 30))
-      (let* ((arrlen (+ 1 (* 2 len)))
-	     (arr (make-float-vector arrlen)))
-	(do ((i (- len) (+ i 1)))
-	    ((= i len))
+      (let ((arrlen (+ 1 (* 2 len))))
+	(do ((arr (make-float-vector arrlen))
+	     (i (- len) (+ i 1)))
+	    ((= i len)
+	     (make-fir-filter arrlen arr))     
 	  (let ((k (+ i len)))
 	    (set! (arr k) 
 		  (if (= i 0)
 		      0.0
 		      (* (/ (cos (* pi i)) i)
-			 (+ .54 (* .46 (cos (/ (* i pi) len)))))))))
-	(make-fir-filter arrlen arr)))))
-
+			 (+ .54 (* .46 (cos (/ (* i pi) len)))))))))))))
+	
 (define differentiator fir-filter)
 
 #|
@@ -987,41 +988,41 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
   (let ((documentation "(make-butter-lp M fc) returns a butterworth low-pass filter; its order is 'M' * 2, 'fc' is the cutoff frequency in Hz"))
     (lambda (M fc)
       (let ((theta (/ (* 2 pi fc) *clm-srate*)))
-	(let ((xcoeffs ())
-	      (ycoeffs ())
-	      (st (sin theta))
-	      (ct (cos theta)))
-	  (do ((k 1 (+ k 1)))
-	      ((> k M))
-	    (let* ((beta (let ((d (* st (sin (/ (* pi (- (* 2 k) 1)) (* 4 M))))))
-			   (* 0.5 (/ (- 1.0 d) (+ 1.0 d)))))
-		   (gamma (* ct (+ 0.5 beta)))
-		   (alpha (* 0.25 (- (+ 0.5 beta) gamma))))
-	      (set! xcoeffs (cons (float-vector (* 2 alpha) (* 4 alpha) (* 2 alpha)) xcoeffs))
-	      (set! ycoeffs (cons (float-vector 1.0 (* -2.0 gamma) (* 2.0 beta)) ycoeffs))))
-	  (make-filter (+ 1 (* 2 M))
-		       (cascade->canonical xcoeffs)
-		       (cascade->canonical ycoeffs)))))))
+	(do ((xcoeffs ())
+	     (ycoeffs ())
+	     (st (sin theta))
+	     (ct (cos theta))
+	     (k 1 (+ k 1)))
+	    ((> k M)
+	     (make-filter (+ 1 (* 2 M))
+			  (cascade->canonical xcoeffs)
+			  (cascade->canonical ycoeffs)))
+	  (let* ((beta (let ((d (* st (sin (/ (* pi (- (* 2 k) 1)) (* 4 M))))))
+			 (* 0.5 (/ (- 1.0 d) (+ 1.0 d)))))
+		 (gamma (* ct (+ 0.5 beta)))
+		 (alpha (* 0.25 (- (+ 0.5 beta) gamma))))
+	    (set! xcoeffs (cons (float-vector (* 2 alpha) (* 4 alpha) (* 2 alpha)) xcoeffs))
+	    (set! ycoeffs (cons (float-vector 1.0 (* -2.0 gamma) (* 2.0 beta)) ycoeffs))))))))
 
 (define make-butter-hp
   (let ((documentation "(make-butter-hp M fc) returns a butterworth high-pass filter; its order is 'M' * 2, 'fc' is the cutoff frequency in Hz"))
     (lambda (M fc)
       (let ((theta (/ (* 2 pi fc) *clm-srate*)))
-	(let ((xcoeffs ())
-	      (ycoeffs ())
-	      (st (sin theta))
-	      (ct (cos theta)))
-	  (do ((k 1 (+ k 1)))
-	      ((> k M))
-	    (let* ((beta (let ((d (* st (sin (/ (* pi (- (* 2 k) 1)) (* 4 M))))))
-			   (* 0.5 (/ (- 1.0 d) (+ 1.0 d)))))
-		   (gamma (* ct (+ 0.5 beta)))
-		   (alpha (* 0.25 (+ 0.5 beta gamma))))
-	      (set! xcoeffs (cons (float-vector (* 2 alpha) (* -4 alpha) (* 2 alpha)) xcoeffs))
-	      (set! ycoeffs (cons (float-vector 1.0 (* -2.0 gamma) (* 2.0 beta)) ycoeffs))))
-	  (make-filter (+ 1 (* 2 M))
-		       (cascade->canonical xcoeffs)
-		       (cascade->canonical ycoeffs)))))))
+	(do ((xcoeffs ())
+	     (ycoeffs ())
+	     (st (sin theta))
+	     (ct (cos theta))
+	     (k 1 (+ k 1)))
+	    ((> k M)
+	     (make-filter (+ 1 (* 2 M))
+			  (cascade->canonical xcoeffs)
+			  (cascade->canonical ycoeffs)))
+	  (let* ((beta (let ((d (* st (sin (/ (* pi (- (* 2 k) 1)) (* 4 M))))))
+			 (* 0.5 (/ (- 1.0 d) (+ 1.0 d)))))
+		 (gamma (* ct (+ 0.5 beta)))
+		 (alpha (* 0.25 (+ 0.5 beta gamma))))
+	    (set! xcoeffs (cons (float-vector (* 2 alpha) (* -4 alpha) (* 2 alpha)) xcoeffs))
+	    (set! ycoeffs (cons (float-vector 1.0 (* -2.0 gamma) (* 2.0 beta)) ycoeffs))))))))
 
 (define make-butter-bp
   (let ((documentation "(make-butter-bp M f1 f2) returns a butterworth band-pass filter; its order is 'M' * 2, 'f1' and 'f2' are the band edge frequencies in Hz"))
@@ -1111,8 +1112,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
        (set! freq-response (cons 0.0 (cons (/ (* 2 (+ i (/ notch-width 2))) cur-srate) freq-response))) ; right bottom y resp hz
        (set! freq-response (cons 1.0 (cons (/ (* 2 (+ i notch-width)) cur-srate) freq-response))))      ; right upper y resp hz
      freqs)
-    (set! freq-response (cons 1.0 (cons 1.0 freq-response)))
-    (reverse freq-response)))
+    (reverse (cons 1.0 (cons 1.0 freq-response)))))
 
 (define notch-channel
   (let ((documentation "(notch-channel freqs filter-order beg dur snd chn edpos (truncate #t) (notch-width 2)) -> notch filter removing freqs"))
@@ -1149,27 +1149,27 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
     (lambda (fr fi n v)
       ;; this is the slow (dft) form
       ;; v=1 -> normal fourier transform
-      (let ((hr (make-float-vector n))
-	    (hi (make-float-vector n))
-	    (ph0 (/ (* v 2 pi) n)))
-	(do ((w 0 (+ 1 w)))
-	    ((= w n))
-	  (let ((sr 0.0)
-		(si 0.0))
-	    (do ((k 0 (+ k 1)))
-		((= k n))
-	      (let ((phase (* ph0 k w)))
-		(let ((c (cos phase))
-		      (s (sin phase))
-		      (x (fr k))
-		      (y (fi k)))
-		  (let ((r (- (* x c) (* y s)))
-			(i (+ (* y c) (* x s))))
-		    (set! sr (+ sr r))
-		    (set! si (+ si i))))))
-	    (set! (hr w) sr)
-	    (set! (hi w) si)))
-	(list hr hi)))))
+      (do ((hr (make-float-vector n))
+	   (hi (make-float-vector n))
+	   (ph0 (/ (* v 2 pi) n))
+	   (w 0 (+ 1 w))
+	   (sr 0.0 0.0)
+	   (si 0.0 0.0))
+	  ((= w n)
+	   (list hr hi))     
+	(do ((k 0 (+ k 1)))
+	    ((= k n))
+	  (let ((phase (* ph0 k w)))
+	    (let ((c (cos phase))
+		  (s (sin phase))
+		  (x (fr k))
+		  (y (fi k)))
+	      (let ((r (- (* x c) (* y s)))
+		    (i (+ (* y c) (* x s))))
+		(set! sr (+ sr r))
+		(set! si (+ si i))))))
+	(set! (hr w) sr)
+	(set! (hi w) si)))))
 
 (define z-transform
   (let ((documentation "(z-transform data n z) performs a Z transform on data; if z=e^2*pi*j/n you get a Fourier transform; complex results in returned vector"))
@@ -1179,15 +1179,15 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
       (let ((res ((if (float-vector? f) make-float-vector make-vector) n)))
 	(do ((w 0 (+ 1 w)))
 	    ((= w n))
-	  (let ((sum 0.0)
-		(t 1.0)
-		(m (expt z w)))
-	    ;; -w?? there seems to be confusion here -- slowzt.cc in the fxt package uses +w
-	    (do ((k 0 (+ k 1)))
-		((= k n))
-	      (set! sum (+ sum (* (f k) t)))
-	      (set! t (* t m)))
-	    (set! (res w) sum)))
+	  (do ((sum 0.0)
+	       (t 1.0)
+	       (m (expt z w))
+	       ;; -w?? there seems to be confusion here -- slowzt.cc in the fxt package uses +w
+	       (k 0 (+ k 1)))
+	      ((= k n)
+	       (set! (res w) sum))
+	    (set! sum (+ sum (* (f k) t)))
+	    (set! t (* t m))))
 	res))))
 
 
@@ -1199,17 +1199,16 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
     (lambda (data) 
       ;; taken from Perry Cook's SignalProcessor.m (the slow version of the Hartley transform)
       (let ((len (length data)) )
-	(let ((arr (make-float-vector len))
-	      (w (/ (* 2.0 pi) len)))
-	  (do ((i 0 (+ i 1)))
-	      ((= i len))
-	    (do ((j 0 (+ j 1)))
-		((= j len))
-	      (set! (arr i) (+ (arr i) 
-			       (* (data j) 
-				  (+ (cos (* i j w)) 
-				     (sin (* i j w))))))))
-	  arr)))))
+	(do ((arr (make-float-vector len))
+	     (w (/ (* 2.0 pi) len))
+	     (i 0 (+ i 1)))
+	    ((= i len) arr)
+	  (do ((j 0 (+ j 1)))
+	      ((= j len))
+	    (set! (arr i) (+ (arr i) 
+			     (* (data j) 
+				(+ (cos (* i j w)) 
+				   (sin (* i j w))))))))))))
 
 (define find-sine
   (let ((documentation "(find-sine freq beg dur snd) returns the amplitude and initial-phase (for sin) at freq"))
@@ -1545,11 +1544,11 @@ shift the given channel in pitch without changing its length.  The higher 'order
 	  (set! *output* summer)
 	  (do ((i 0 (+ i 1)))
 	      ((= i pairs))
-	    (let ((gen (vector-ref ssbs i))
-		  (filt (vector-ref bands i)))
-	      (do ((k 0 (+ k 1)))
-		  ((= k len))
-		(outa k (ssb-am gen (bandpass filt (ina k data))))))) ; outa adds, (ina i v) is the same as (float-vector-ref v i)
+	    (do ((gen (vector-ref ssbs i))
+		 (filt (vector-ref bands i))
+		 (k 0 (+ k 1)))
+		((= k len))
+	      (outa k (ssb-am gen (bandpass filt (ina k data)))))) ; outa adds, (ina i v) is the same as (float-vector-ref v i)
 	  (set! *output* #f)
 	  (float-vector-scale! summer (/ mx (float-vector-peak summer)))
 	  (float-vector->channel summer beg len snd chn current-edit-position
@@ -1583,12 +1582,12 @@ shift the given channel in pitch without changing its length.  The higher 'order
 	  (set! *output* summer)
 	  (do ((i 0 (+ i 1)))
 	      ((= i pairs))
-	    (let ((gen (vector-ref ssbs i))
-		  (filt (vector-ref bands i))
-		  (e (vector-ref frenvs i)))
-	      (do ((k 0 (+ k 1)))
-		  ((= k len))
-		(outa k (ssb-am gen (bandpass filt (ina k data)) (env e))))))
+	    (do ((gen (vector-ref ssbs i))
+		 (filt (vector-ref bands i))
+		 (e (vector-ref frenvs i))
+		 (k 0 (+ k 1)))
+		((= k len))
+	      (outa k (ssb-am gen (bandpass filt (ina k data)) (env e)))))
 	  (set! *output* #f)
 	  (float-vector-scale! summer (/ mx (float-vector-peak summer)))
 	  (float-vector->channel summer beg len snd chn current-edit-position
@@ -1821,7 +1820,9 @@ the rendering frequency, the number of measurements per second; 'db-floor' is th
 
 (define harmonicizer 
   (let ((documentation "(harmonicizer freq coeffs pairs (order 40) (bw 50.0) (beg 0) dur snd chn edpos) splits out each harmonic \
-and replaces it with the spectrum given in coeffs"))
+and replaces it with the spectrum given in coeffs")
+	(startup 40))
+	
     (lambda* (freq coeffs pairs (order 40) (bw 50.0) (beg 0) dur snd chn edpos)
       (let ((bands (make-vector pairs))
 	    (pcoeffs (partials->polynomial coeffs))
@@ -1829,7 +1830,6 @@ and replaces it with the spectrum given in coeffs"))
 	    (peaks2 (make-vector pairs))
 	    (flt (make-filter 2 (float-vector 1 -1) (float-vector 0 -0.9)))
 	    (old-mx (maxamp))
-	    (startup 40)
 	    (len (- (or dur (framples snd chn edpos)) beg)))
 	(let ((summer (make-float-vector len))
 	      (indata (channel->float-vector beg len snd chn edpos)))
@@ -1846,24 +1846,24 @@ and replaces it with the spectrum given in coeffs"))
 	  ;; ignore startup
 	  (do ((k 0 (+ k 1)))
 	      ((= k startup))
-	    (let ((sum 0.0))
-	      (do ((i 0 (+ i 1)))
-		  ((= i pairs))
-		(let ((sig (bandpass (vector-ref bands i) (float-vector-ref indata k))))
-		  (set! sum (+ sum (* (moving-max (vector-ref peaks i) sig)
-				      (polynomial pcoeffs (* sig (moving-norm (vector-ref peaks2 i) sig))))))))
-	      (filter flt sum)))
-	  
+	    (do ((sum 0.0)
+		 (i 0 (+ i 1)))
+		((= i pairs)
+		 (filter flt sum))
+	      (let ((sig (bandpass (vector-ref bands i) (float-vector-ref indata k))))
+		(set! sum (+ sum (* (moving-max (vector-ref peaks i) sig)
+				    (polynomial pcoeffs (* sig (moving-norm (vector-ref peaks2 i) sig)))))))))
+
 	  (set! *output* summer)
 	  (do ((pair 0 (+ pair 1)))
 	      ((= pair pairs))
-	    (let ((bp (vector-ref bands pair))
-		  (pk (vector-ref peaks pair))
-		  (pk2 (vector-ref peaks2 pair)))
-	      (do ((k startup (+ k 1)))
-		  ((= k len))
-		(let ((x (bandpass bp (float-vector-ref indata k))))
-		  (outa k (* (moving-max pk x) (polynomial pcoeffs (* x (moving-norm pk2 x)))))))))
+	    (do ((bp (vector-ref bands pair))
+		 (pk (vector-ref peaks pair))
+		 (pk2 (vector-ref peaks2 pair))
+		 (k startup (+ k 1)))
+		((= k len))
+	      (let ((x (bandpass bp (float-vector-ref indata k))))
+		(outa k (* (moving-max pk x) (polynomial pcoeffs (* x (moving-norm pk2 x))))))))
 
 	      ;; we're normalizing the polynomial input so its waveshaping index is more-or-less 1.0
 	      ;;   this might work better with len=256, max .1 -- we're assuming a well-behaved signal 
@@ -1900,12 +1900,12 @@ and replaces it with the spectrum given in coeffs"))
 		   (outa samp
 			 (let ((pos intrp))
 			   (if (>= pos 1.0)
-			       (let ((num (floor pos)))
-				 (do ((i 0 (+ i 1)))
-				     ((= i num))
-				   (set! last next)
-				   (set! next (read-sample rd)))
-				 (set! pos (- pos num))))
+			       (do ((num (floor pos))
+				    (i 0 (+ i 1)))
+				   ((= i num)
+				    (set! pos (- pos num)))
+				 (set! last next)
+				 (set! next (read-sample rd))))
 			   (set! intrp (+ pos sr))
 			   (+ last (* pos (- next last))))))))))
 	(set-samples 0 (- (framples tempfile) 1) tempfile snd chn #t "linear-src" 0 #f #t)
@@ -2307,10 +2307,10 @@ is assumed to be outside -1.0 to 1.0."))
       (let ((index (or snd (selected-sound) (car (sounds)))))
 	(if (not (sound? index))
 	    (error 'no-such-sound (list "unclip-sound" snd))
-	    (let ((chns (channels index)))
-	      (do ((chn 0 (+ 1 chn)))
-		  ((= chn chns))
-		(unclip-channel index chn))))))))
+	    (do ((chns (channels index))
+		 (chn 0 (+ 1 chn)))
+		((= chn chns))
+	      (unclip-channel index chn)))))))
 
 
 (define* (kalman-filter-channel (Q 1.0e-5))
@@ -2365,62 +2365,59 @@ is assumed to be outside -1.0 to 1.0."))
 	   (let ((cols (make-vector n 0))
 		 (rows (make-vector n 0))
 		 (pivots (make-vector n 0)))
-	     (do ((i 0 (+ i 1)))
+	     (do ((i 0 (+ i 1))
+		  (col 0 0)
+		  (row 0 0))
 		 ((= i n))
-	       (let ((col 0)
-		     (row 0))
-		 (let ((biggest 0.0))
-		   (do ((j 0 (+ j 1)))
-		       ((= j n))
-					;(format () "j: ~A, n: ~A~%" j n)
-		     (if (not (= (pivots j) 1))
-			 (do ((k 0 (+ k 1)))
-			     ((= k n))
-			   (if (= (pivots k) 0)
-			       (let ((val (abs (matrix j k))))
-				 (if (> val biggest)
-				     (begin
-				       (set! col k)
-				       (set! row j)
-					;(format () "k: ~A, row: ~D, col: ~A~%" k row col)
-				       (set! biggest val))))
-			       (if (> (pivots k) 1)
-				   (return #f))))))
-		   (if (< biggest zero) 
-		       (return #f))) ; this can be fooled (floats...): (invert-matrix (make-share-vector (float-vector 1 2 3 3 2 1 4 5 6) (list 3 3)))
-		 (set! (pivots col) (+ (pivots col) 1))
-					;(format () "i: ~D, row: ~D, col: ~A~%" i row col)
-		 (if (not (= row col))
-		     (let ((temp (if (sequence? b) (b row) 0.0)))
-		       (if (sequence? b)
-			   (begin
-			     (set! (b row) (b col))
-			     (set! (b col) temp)))
-		       (do ((k 0 (+ k 1)))
-			   ((= k n))
-			 (set! temp (matrix row k))
-			 (set! (matrix row k) (matrix col k))
-			 (set! (matrix col k) temp))))
-		 (set! (cols i) col)
-		 (set! (rows i) row)
-		 ;; round-off troubles here
-		 (if (< (abs (matrix col col)) zero)
-		     (return #f))
-		 (let ((inverse-pivot (/ 1.0 (matrix col col))))
-		   (set! (matrix col col) 1.0)
-		   (do ((k 0 (+ k 1)))
-		       ((= k n))
-		     (set! (matrix col k) (* inverse-pivot (matrix col k))))
-		   (if b (set! (b col) (* inverse-pivot (b col)))))
+	       (do ((biggest 0.0)
+		    (j 0 (+ j 1)))
+		   ((= j n)
+		    (if (< biggest zero) 
+			(return #f))) ; this can be fooled (floats...): (invert-matrix (make-share-vector (float-vector 1 2 3 3 2 1 4 5 6) (list 3 3)))
+		 (if (not (= (pivots j) 1))
+		     (do ((k 0 (+ k 1)))
+			 ((= k n))
+		       (if (= (pivots k) 0)
+			   (let ((val (abs (matrix j k))))
+			     (if (> val biggest)
+				 (begin
+				   (set! col k)
+				   (set! row j)
+				   (set! biggest val))))
+			   (if (> (pivots k) 1)
+			       (return #f))))))
+	       (set! (pivots col) (+ (pivots col) 1))
+	       (if (not (= row col))
+		   (let ((temp (if (sequence? b) (b row) 0.0)))
+		     (if (sequence? b)
+			 (begin
+			   (set! (b row) (b col))
+			   (set! (b col) temp)))
+		     (do ((k 0 (+ k 1)))
+			 ((= k n))
+		       (set! temp (matrix row k))
+		       (set! (matrix row k) (matrix col k))
+		       (set! (matrix col k) temp))))
+	       (set! (cols i) col)
+	       (set! (rows i) row)
+	       ;; round-off troubles here
+	       (if (< (abs (matrix col col)) zero)
+		   (return #f))
+	       (let ((inverse-pivot (/ 1.0 (matrix col col))))
+		 (set! (matrix col col) 1.0)
 		 (do ((k 0 (+ k 1)))
 		     ((= k n))
-		   (if (not (= k col))
-		       (let ((scl (matrix k col)))
-			 (set! (matrix k col) 0.0)
-			 (do ((m 0 (+ 1 m)))
-			     ((= m n))
-			   (set! (matrix k m) (- (matrix k m) (* scl (matrix col m)))))
-			 (if b (set! (b k) (- (b k) (* scl (b col))))))))))
+		   (set! (matrix col k) (* inverse-pivot (matrix col k))))
+		 (if b (set! (b col) (* inverse-pivot (b col)))))
+	       (do ((k 0 (+ k 1)))
+		   ((= k n))
+		 (if (not (= k col))
+		     (let ((scl (matrix k col)))
+		       (set! (matrix k col) 0.0)
+		       (do ((m 0 (+ 1 m)))
+			   ((= m n))
+			 (set! (matrix k m) (- (matrix k m) (* scl (matrix col m)))))
+		       (if b (set! (b k) (- (b k) (* scl (b col)))))))))
 	     (do ((i (- n 1) (- i 1)))
 		 ((< i 0))
 	       (if (not (= (rows i) (cols i)))
@@ -2579,23 +2576,22 @@ the multi-modulator FM case described by the list of modulator frequencies and i
 ;;; waveshaping harmonic amplitude at a given index
 
 (define (cheby-hka k a coeffs) ; (coeff 0 = DC)
-  (let ((sum 0.0)
-	(n (length coeffs)))
-    (do ((j 0 (+ j 1)))
-	((= j n))
-      (let ((dsum 0.0)
-	    (p (+ k (* 2 j))))
-	(do ((i 0 (+ i 1)))
-	    ((>= (+ p (* 2 i)) n))
-	  (set! dsum (+ dsum (* (expt -1 i)
-				(coeffs (+ p (* 2 i)))
-				(+ (binomial (+ p i) i)
-				   (binomial (+ p i -1) (- i 1)))))))
-	(set! sum (+ sum (* dsum 
-			    (expt a p)
-			    (binomial p j))))))
-    sum))
-
+  (do ((sum 0.0)
+       (n (length coeffs))
+       (j 0 (+ j 1)))
+      ((= j n)
+       sum)
+    (do ((dsum 0.0)
+	 (p (+ k (* 2 j)))
+	 (i 0 (+ i 1)))
+	((>= (+ p (* 2 i)) n)
+	 (set! sum (+ sum (* dsum 
+			     (expt a p)
+			     (binomial p j)))))
+      (set! dsum (+ dsum (* (expt -1 i)
+			    (coeffs (+ p (* 2 i)))
+			    (+ (binomial (+ p i) i)
+			       (binomial (+ p i -1) (- i 1)))))))))
 #|
 (with-sound ()
   (let ((gen (make-polyshape 1000.0 :partials (list 1 .5  2 .25  3 .125  4 .125))))
@@ -2627,23 +2623,23 @@ the multi-modulator FM case described by the list of modulator frequencies and i
 	 (len (length partials))
 	 (topk 0)
 	 (DC 0.0)
-	 (original-sum (let ((sum 0.0))
-			 (do ((i 0 (+ i 2)))
-			     ((>= i len) sum)
-			   (let ((hnum (partials i))
-				 (amp (partials (+ i 1))))
-			     (if (= hnum 0)
-				 (set! DC amp)
-				 (begin
-				   (set! topk (max topk hnum))
-				   (set! sum (+ sum amp))))))))
+	 (original-sum (do ((sum 0.0)
+			    (i 0 (+ i 2)))
+			   ((>= i len) sum)
+			 (let ((hnum (partials i))
+			       (amp (partials (+ i 1))))
+			   (if (= hnum 0)
+			       (set! DC amp)
+			       (begin
+				 (set! topk (max topk hnum))
+				 (set! sum (+ sum amp)))))))
 	 (min-sum original-sum)
-	 (original-partials (let ((v (make-float-vector topk)))
-			      (do ((i 0 (+ i 2)))
-				  ((>= i len) v)
-				(let ((hnum (partials i)))
-				  (if (not (= hnum 0))
-				      (set! (v (- hnum 1)) (partials (+ i 1))))))))
+	 (original-partials (do ((v (make-float-vector topk))
+				 (i 0 (+ i 2)))
+				((>= i len) v)
+			      (let ((hnum (partials i)))
+				(if (not (= hnum 0))
+				    (set! (v (- hnum 1)) (partials (+ i 1)))))))
 	 (min-partials (copy original-partials)))
     
     (if (<= topk (log tries 2))
