@@ -1,4 +1,4 @@
-;;; various envelope functions
+;;; Various envelope functions
 ;;;
 ;;; window-envelope (beg end env) -> portion of env lying between x axis values beg and end
 ;;; map-envelopes (func env1 env2) maps func over the breakpoints in env1 and env2 returning a new envelope
@@ -85,12 +85,11 @@ end: (window-envelope 1.0 3.0 '(0.0 0.0 5.0 1.0)) -> '(1.0 0.2 3.0 0.6)"))
 			(ee2 (at0 e2))
 			(newe ()))
 		    (set! xs (sort! (remove-duplicates xs) <))
-		    (let ((len (length xs)))
-		      (do ((i 0 (+ i 1)))
-			  ((= i len))
-			(let ((x (xs i)))
-			  (set! newe (append newe (list x (op (envelope-interp x ee1) (envelope-interp x ee2)))))))
-		      newe)))))))))
+		    (do ((len (length xs))
+			 (i 0 (+ i 1)))
+			((= i len) newe)
+		      (let ((x (xs i)))
+			(set! newe (append newe (list x (op (envelope-interp x ee1) (envelope-interp x ee2)))))))))))))))
 
 
 ;;; -------- multiply-envelopes, add-envelopes
@@ -145,10 +144,9 @@ envelope: (multiply-envelopes '(0 0 2 .5) '(0 0 1 2 2 1)) -> '(0 0 0.5 0.5 1.0 0
 (define envelope-last-x 
   (let ((documentation "(envelope-last-x env) -> max x axis break point position"))
     (lambda (e)
-      (if (null? (cddr e))
-	  (car e)
-	  (envelope-last-x (cddr e))))))
-
+      (do ((e e (cddr e))) 
+	  ((null? (cddr e))
+	   (car e))))))
 
 ;;; -------- stretch-envelope
 
@@ -310,11 +308,11 @@ repetition to be in reverse."))
 		      (set! new-env (cons first-y (cons x new-env)))))))
 	    (set! new-env (reverse new-env))
 	    (if normalized
-		(let ((scl (/ x-max x))
-		      (new-len (length new-env)))
-		  (do ((i 0 (+ i 2)))
-		      ((>= i new-len))
-		    (set! (new-env i) (* scl (new-env i))))))
+		(do ((scl (/ x-max x))
+		     (new-len (length new-env))
+		     (i 0 (+ i 2)))
+		    ((>= i new-len))
+		  (set! (new-env i) (* scl (new-env i)))))
 	    new-env))))))
 
 
@@ -433,19 +431,18 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"))
 	(let ((largest-diff (* 1.0 (- (max-envelope e) mn)))
 	      (x-min (car e))
 	      (x-max (e (- (length e) 2))))
-	  (let ((x-incr (* 1.0 (/ (- x-max x-min) xgrid)))
-		(new-e ()))
-	    (do ((x x-min (+ x x-incr)))
-		((>= x x-max))
-	      (let ((y (envelope-interp x e)))
-		(set! new-e (cons (if (= largest-diff 0.0)
-				      y
-				      (+ mn
-					 (* largest-diff
-					    (expt (/ (- y mn) largest-diff) power))))
-				  (cons x new-e)))))
-	    (reverse new-e)))))))
-
+	  (do ((x-incr (* 1.0 (/ (- x-max x-min) xgrid)))
+	       (new-e ())
+	       (x x-min (+ x x-incr)))
+	      ((>= x x-max)
+	       (reverse new-e))     
+	    (let ((y (envelope-interp x e)))
+	      (set! new-e (cons (if (= largest-diff 0.0)
+				    y
+				    (+ mn
+				       (* largest-diff
+					  (expt (/ (- y mn) largest-diff) power))))
+				(cons x new-e))))))))))
 
 ;;; rms-envelope
 
@@ -505,7 +502,7 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"))
   ;; the smaller the grid, the less likely a given bump will get through
   ;; original x and y values are not changed, just sometimes omitted.
   
-  (define (point-on-line? px py qx qy tx ty)
+  (define (point-on-line px py qx qy tx ty)
     
     ;; is point tx ty on line defined by px py and qx qy --
     ;; #f if no, :before if on ray from p, :after if on ray from q, :within if between p and q
@@ -534,30 +531,31 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"))
 	    (xmin (car env1)))
 	(if (= ymin ymax)
 	    (list xmin ymin xmax ymax)
-	    (let ((y-scl (/ ygrid (- ymax ymin)))
-		  (x-scl (/ (or xgrid ygrid) (- xmax xmin)))
-		  (px #f) (py #f)
-		  (qx #f) (qy #f) 
-		  (tx #f) (ty #f) 
-		  (qtx #f) (qty #f))
-	      (do ((i 0 (+ i 2)))
-		  ((>= i (length env1)))
-		(let ((ttx (env1 i))
-		      (tty (env1 (+ i 1))))
-		  (set! tx (round (* ttx x-scl)))
-		  (set! ty (round (* tty y-scl)))
-		  (if px
-		      (if (not (point-on-line? px py qx qy tx ty))
-			  (begin
-			    (set! new-env (cons qty (cons qtx new-env)))
-			    (set! px qx)
-			    (set! py qy)))
-		      (begin
-			(set! px qx)
-			(set! py qy)))
-		  (set! qx tx)
-		  (set! qy ty)
-		  (set! qtx ttx)
-		  (set! qty tty)))
-	      (set! new-env (cons qty (cons qtx new-env)))
-	      (reverse new-env))))))
+	    (do ((y-scl (/ ygrid (- ymax ymin)))
+		 (x-scl (/ (or xgrid ygrid) (- xmax xmin)))
+		 (px #f) (py #f)
+		 (qx #f) (qy #f) 
+		 (tx #f) (ty #f) 
+		 (qtx #f) (qty #f)
+		 (i 0 (+ i 2)))
+		((>= i (length env1))
+		 (set! new-env (cons qty (cons qtx new-env)))
+		 (reverse new-env))
+	      (let ((ttx (env1 i))
+		    (tty (env1 (+ i 1))))
+		(set! tx (round (* ttx x-scl)))
+		(set! ty (round (* tty y-scl)))
+		(if px
+		    (if (not (point-on-line px py qx qy tx ty))
+			(begin
+			  (set! new-env (cons qty (cons qtx new-env)))
+			  (set! px qx)
+			  (set! py qy)))
+		    (begin
+		      (set! px qx)
+		      (set! py qy)))
+		(set! qx tx)
+		(set! qy ty)
+		(set! qtx ttx)
+		(set! qty tty)))))))
+	    
\ No newline at end of file
