@@ -56,12 +56,11 @@
 		 (search-point (cddr e)))))))
       
     (define (envelope-position x cur-env)
-      (let search-point ((e cur-env)
-                         (pos 0))
-        (if (= (car e) x)
-            pos
-            (search-point (cddr e) (+ pos 2)))))
-    
+      (do ((e cur-env (cddr e))
+	   (pos 0 (+ pos 2)))
+	  ((= (car e) x) 
+	   pos)))
+
     (letrec ((on-dot? (let ((mouse-radius .03))
 			(lambda (x y cur-env pos)
 			  (and (pair? cur-env)
@@ -92,14 +91,12 @@
     ;; point exists, needs to be edited with check for various bounds
     
     (define (edit-envelope-point pos x y cur-env)
-      (let ((new-env ()))
-	(let search-point ((e cur-env)
-			   (npos 0))
-	  (if (= npos pos)
-	      (append new-env (list x y) (cddr e))
-	      (begin
-		(set! new-env (append new-env (list (car e) (cadr e))))
-		(search-point (cddr e) (+ npos 2)))))))
+      (do ((new-env ())
+	   (e cur-env (cddr e))
+	   (npos 0 (+ npos 2)))
+	  ((= npos pos) 
+	   (append new-env (list x y) (cddr e)))
+	(set! new-env (append new-env (list (car e) (cadr e))))))
 
     (let ((cur-env (channel-envelope snd chn)))
       (let ((lx (if (= mouse-pos 0)
@@ -148,17 +145,17 @@
   (let ((snd (hook 'snd))
 	(chn (hook 'chn))
 	(key (hook 'key))
-	(state (hook 'state)))
+	(state4 (= (hook 'state) 4)))
     
     ;; C-g returns to original env
     ;; C-. applies current env to amplitude
     (if (and (= key (char->integer #\.))
-	     (= state 4))
+	     state4)
 	(begin
 	  (env-channel (channel-envelope snd chn) 0 (framples snd chn) snd chn)
 	  (set! (hook 'result) #t))
 	(if (and (= key (char->integer #\g))
-		 (= state 4))
+		 state4)
 	    (begin
 	      (set! (channel-envelope snd chn) '(0.0 1.0 1.0 1.0))
 	      (set! (hook 'result) #t))))))
@@ -189,17 +186,17 @@
 (define play-with-envs
   (let ((documentation "(play-with-envs snd) sets channel amps during playback from the associated enved envelopes"))
     (lambda* (sound)
-      (let ((chans (channels sound)))
-	(do ((chan 0 (+ 1 chan)))
-	    ((= chan chans))
-	  (let ((player (make-player sound chan))
-		(e (make-env (channel-envelope sound chan) 
-			     :length (floor (/ (framples sound chan) *dac-size*)))))
-	    (add-player player 0 -1 -1 (lambda (reason) (set! (hook-functions play-hook) ())))
-	    (hook-push play-hook (lambda (hook)
-				   ;; if dac buffer size in framples is not dac-size, we should do something debonair
-				   (set! (amp-control player) (env e))))))
-	(start-playing chans (srate sound))))))
+      (do ((chans (channels sound))
+	   (chan 0 (+ 1 chan)))
+	  ((= chan chans)
+	   (start-playing chans (srate sound)))   
+	(let ((player (make-player sound chan))
+	      (e (make-env (channel-envelope sound chan) 
+			   :length (floor (/ (framples sound chan) *dac-size*)))))
+	  (add-player player 0 -1 -1 (lambda (reason) (set! (hook-functions play-hook) ())))
+	  (hook-push play-hook (lambda (hook)
+				 ;; if dac buffer size in framples is not dac-size, we should do something debonair
+				 (set! (amp-control player) (env e)))))))))
 
 #|
 (define play-panned 
