@@ -86,7 +86,7 @@
 	  (format () ";;; freeverb: ~d input channels, ~d output channels~%" in-chans out-chans))
       (if (and (> in-chans 1)
 	       (not (= in-chans out-chans)))
-	  (error "input must be mono or input channels must equal output channels"))
+	  (error 'wrong-type-arg "input must be mono or input channels must equal output channels"))
 
       (let ((out-mix (or output-mixer
 		       (let ((v (make-float-vector (list out-chans out-chans))))
@@ -105,9 +105,8 @@
 	    ((= c out-chans))
 	  (do ((i 0 (+ i 1)))
 	      ((= i numcombs))
-	    (let* ((tuning (combtuning i))
-		   (len (floor (* srate-scale tuning)))
-		   (dmp (* scale-damping (if (number? damping) damping (damping i)))))
+	    (let ((len (floor (* srate-scale (combtuning i))))
+		  (dmp (* scale-damping (if (number? damping) damping (damping i)))))
 	      (if (odd? c)
 		  (set! len (+ len (floor (* srate-scale stereo-spread)))))
 	      (set! (fcombs (+ (* c numcombs) i))
@@ -118,8 +117,7 @@
 	    ((= c out-chans))
 	  (do ((i 0 (+ i 1)))
 	      ((= i numallpasses))
-	    (let* ((tuning (allpasstuning i))
-		   (len (floor (* srate-scale tuning))))
+	    (let ((len (floor (* srate-scale (allpasstuning i)))))
 	      (if (odd? c)
 		  (set! len (+ len (floor (* srate-scale stereo-spread)))))
 	      (set! (allpasses (+ (* c numallpasses) i))
