@@ -37,7 +37,7 @@
       (let ((ms (marks (selected-sound) (selected-channel))))
 	(if (> (length ms) 1)
 	    (map mark->integer (list (car ms) (cadr ms)))
-	    (list))))))
+	    ())))))
 
 
 ;;; -------- Play between by marks
@@ -637,15 +637,16 @@ between two marks,using the granulate generator to fix up the selection duration
     (define loop-data '(0 0 0 0 0 0 1 1))
     
     (define (update-labels start range end sus-rel range-in-secs)
-      (if range-in-secs
-	  (begin
-	    (change-label start (format #f "~,3F" (/ (loop-data (* sus-rel 2)) (srate))))
-	    (change-label range (format #f "~,3F" (/ (- (loop-data (+ 1 (* sus-rel 2))) (loop-data (* sus-rel 2))) (srate))))
-	    (change-label end (format #f "~,3F" (/ (loop-data (+ 1 (* sus-rel 2))) (srate)))))
-	  (begin
-	    (change-label start (format #f "~D" (loop-data (* sus-rel 2))))
-	    (change-label range (format #f "~D" (- (loop-data (+ 1 (* sus-rel 2))) (loop-data (* sus-rel 2)))))
-	    (change-label end (format #f "~D" (loop-data (+ 1 (* sus-rel 2))))))))
+      (let ((sr2 (* sus-rel 2)))
+	(if range-in-secs
+	    (begin
+	      (change-label start (format #f "~,3F" (/ (loop-data sr2) (srate))))
+	      (change-label range (format #f "~,3F" (/ (- (loop-data (+ 1 sr2)) (loop-data sr2)) (srate))))
+	      (change-label end (format #f "~,3F" (/ (loop-data (+ 1 sr2)) (srate)))))
+	    (begin
+	      (change-label start (format #f "~D" (loop-data sr2)))
+	      (change-label range (format #f "~D" (- (loop-data (+ 1 sr2)) (loop-data sr2))))
+	      (change-label end (format #f "~D" (loop-data (+ 1 sr2))))))))
     
     (define (create-loop-dialog)
       (unless (Widget? loop-dialog)
@@ -849,29 +850,29 @@ between two marks,using the granulate generator to fix up the selection duration
 		 
 		 (for-each
 		  (lambda (rparent loc)
-		    (let ((sus-rel-start (* offset 2)))
+		    (let ((sus-rel-start (+ (* offset 2) 1)))
 		      (let ((someright (XtCreateManagedWidget " > " xmPushButtonWidgetClass rparent ())))
 			(XtAddCallback someright XmNactivateCallback
 				       (lambda (w c i)
-					 (let ((ml (if (= loc 0) (loop-data (+ sus-rel-start 1)) (framples))))
+					 (let ((ml (if (= loc 0) (loop-data sus-rel-start) (framples))))
 					   (set! (loop-data (+ loc (* offset 2))) (min ml (+ (loop-data (+ loc (* offset 2))) 1)))
 					   (update-labels midlab1 midlab2 midlab3 offset range-in-secs)))))
 		      (let ((lotsright (XtCreateManagedWidget " >>" xmPushButtonWidgetClass rparent ())))
 			(XtAddCallback lotsright XmNactivateCallback
 				       (lambda (w c i)
-					 (let ((ml (if (= loc 0) (loop-data (+ sus-rel-start 1)) (framples))))
+					 (let ((ml (if (= loc 0) (loop-data sus-rel-start) (framples))))
 					   (set! (loop-data (+ loc (* offset 2))) (min ml (+ (loop-data (+ loc (* offset 2))) 10)))
 					   (update-labels midlab1 midlab2 midlab3 offset range-in-secs)))))
 		      (let ((stopright (XtCreateManagedWidget " O " xmPushButtonWidgetClass rparent ())))
 			(XtAddCallback stopright XmNactivateCallback
 				       (lambda (w c i)
-					 (let ((ml (if (= loc 0) (loop-data (+ sus-rel-start 1)) (framples))))
+					 (let ((ml (if (= loc 0) (loop-data sus-rel-start) (framples))))
 					   (set! (loop-data (+ loc (* offset 2))) ml)
 					   (update-labels midlab1 midlab2 midlab3 offset range-in-secs)))))
 		      (let ((farright (XtCreateManagedWidget ">>" xmPushButtonWidgetClass rparent ())))
 			(XtAddCallback farright XmNactivateCallback
 				       (lambda (w c i)
-					 (let ((ml (if (= loc 0) (loop-data (+ sus-rel-start 1)) (framples))))
+					 (let ((ml (if (= loc 0) (loop-data sus-rel-start) (framples))))
 					   (set! (loop-data (+ loc (* offset 2))) ml)
 					   (update-labels midlab1 midlab2 midlab3 offset range-in-secs)))))))
 		  (list rowrighttop rowrightbottom)
