@@ -363,7 +363,7 @@ last end of the mixes in 'mix-list'"))
   (let ((documentation "(syncd-mixes val) returns a list (possibly null) of all mixes whose mix-sync field is set to 'val'"))
     (lambda (val)
       (if (<= val 0)
-	  (list)
+	  ()
 	  (let ((mix-list ()))
 	    (for-each
 	     (lambda (snd-m)
@@ -426,13 +426,13 @@ panning operation."))
 		   (cons (car e) (cons (- 1.0 (cadr e)) (invert-envelope (cddr e))))))
 	     
 	     (let ((incoming-chans (channels name))
-		   (receiving-chans (channels index)))
+		   (receiving-mono (= (channels index) 1)))
 	       
 	       (if (= incoming-chans 1)
 		   
 		   ;; mono input
 		   
-		   (if (= receiving-chans 1)
+		   (if receiving-mono
 		       
 		       ;; mono to mono = just scale or envelope
 		       (let ((idx (mix name beg 0 index 0 *with-mix-tags* auto-delete))) ; file start in-chan snd chn ...
@@ -457,7 +457,7 @@ panning operation."))
 		   
 		   ;; stero input
 		   
-		   (if (= receiving-chans 1)
+		   (if receiving-mono
 		       
 		       ;; stereo -> mono => scale or envelope both input chans into the output
 		       (let ((idx0 (mix name beg 0 index 0 *with-mix-tags* deletion-choice))
@@ -549,10 +549,10 @@ begin time of each mix that starts after beg in the given channel"))
       (if (not snd)
 	  (for-each check-mix-tags (sounds))
 	  (if (not chn)
-	      (let ((chns (channels snd)))
-		(do ((i 0 (+ i 1)))
-		    ((= i chns))
-		  (check-mix-tags snd i)))
+	      (do ((chns (channels snd))
+		   (i 0 (+ i 1)))
+		  ((= i chns))
+		(check-mix-tags snd i))
 	      (let ((mxs (mixes snd chn))
 		    (changed #f))
 		(let check-mix ((mx (car mxs))
