@@ -283,7 +283,7 @@
 		  'string->symbol         (lambda (obj) (#_string->symbol (obj 'value)))
 		  'symbol                 (lambda (obj) (#_symbol (obj 'value)))
 		  'gensym                 (lambda (obj) (#_gensym (obj 'value)))
-		  'make-keyword           (lambda (obj) (#_make-keyword (obj 'value)))
+		  'string->keyword        (lambda (obj) (#_string->keyword (obj 'value)))
 		  'open-input-string      (lambda (obj) (#_open-input-string (obj 'value)))
 		  'call-with-input-string (lambda (obj f) (#_call-with-input-string (obj 'value) f))
 		  'with-input-from-string (lambda (obj f) (#_with-input-from-string (obj 'value) f))
@@ -292,7 +292,7 @@
 		  'getenv                 (lambda (obj) (#_getenv (obj 'value)))
 		  'delete-file            (lambda (obj) (#_delete-file (obj 'value)))
 		  'system                 (lambda* (obj cap) (#_system (obj 'value) cap))
-		  '->byte-vector           (lambda (obj) (#_->byte-vector (obj 'value))) ; this is in-place! 
+		  'string->byte-vector    (lambda (obj) (#_string->byte-vector (obj 'value))) ; this is in-place! 
 		  'load                   (lambda* (obj (e (curlet))) (#_load (obj 'value) e))
 		  'eval-string            (lambda* (obj (e (curlet))) (#_eval-string (obj 'value) e))
 		  'char-position          (make-local-method #_char-position)
