@@ -13,9 +13,9 @@
   ;; output-scale can be used to boost the reverb output
 
   (let ((dly-len (if (= (floor *clm-srate*) 44100)
-		     (vector 2467 2753 3217 3533 3877 4127 599 197 67 101 97 73 67 53 37)
+		     #(2467 2753 3217 3533 3877 4127 599 197 67 101 97 73 67 53 37)
 		     (and (= (floor *clm-srate*) 22050)
-			  (vector 1237 1381 1607 1777 1949 2063 307 97 31 53 47 37 31 29 17))))
+			  #(1237 1381 1607 1777 1949 2063 307 97 31 53 47 37 31 29 17))))
 	(chan2 (> (channels *output*) 1))
 	(chan4 (= (channels *output*) 4)))
 	
@@ -23,15 +23,17 @@
 	(let ((srscale (/ *clm-srate* 25641)))
 
 	  (define (next-prime val)
-	    (if (or (= val 2)
-		    (and (odd? val)
-			 (do ((i 3 (+ i 2))
-			      (lim (sqrt val)))
-			     ((or (= 0 (modulo val i)) (> i lim)) (> i lim)))))
-		val
-		(next-prime (+ val 2))))
+	    (do ((val val (+ val 2)))
+		((or (= val 2)
+		     (and (odd? val)
+			  (do ((i 3 (+ i 2))
+			       (lim (sqrt val)))
+			      ((or (= 0 (modulo val i))
+				   (> i lim))
+			       (> i lim)))))
+		 val)))
 
-	  (set! dly-len (vector 1433 1601 1867 2053 2251 2399 347 113 37 59 53 43 37 29 19))
+	  (set! dly-len #(1433 1601 1867 2053 2251 2399 347 113 37 59 53 43 37 29 19))
 	  (do ((i 0 (+ i 1)))
 	      ((= i 15))
 	    (let ((val (floor (* srscale (dly-len i)))))
