@@ -19,20 +19,20 @@
 (define vector-add! 
   (let ((documentation "(vector-add! p1 p2) adds (elementwise) the vectors p1 and p2"))
     (lambda (p1 p2)
-      (let ((len (min (length p1) (length p2)))) 
-	(do ((i 0 (+ i 1)))
-	    ((= i len))
-	  (set! (p1 i) (+ (p1 i) (p2 i))))
-	p1))))
+      (do ((len (min (length p1) (length p2)))
+	   (i 0 (+ i 1)))
+	  ((= i len))
+	(set! (p1 i) (+ (p1 i) (p2 i))))
+      p1)))
 
 (define vector-scale! 
   (let ((documentation "(vector-scale! p1 scl) scales each element of the vector p1 by scl"))
     (lambda (p1 scl)
-      (let ((len (length p1)))
-	(do ((i 0 (+ i 1)))
-	    ((= i len))
-	  (set! (p1 i) (* scl (p1 i))))
-	p1))))
+      (do ((len (length p1))
+	   (i 0 (+ i 1)))
+	  ((= i len))
+	(set! (p1 i) (* scl (p1 i))))
+      p1)))
 
 (define poly-as-vector-eval 
   (let ((documentation "(poly-as-vector-eval v x) treats 'v' as a vector of polynomial coefficients, returning the value of the polynomial at x"))
@@ -103,15 +103,14 @@
 	  (vector-scale! (copy p2) p1)
 	  (if (not (vector? p2))
 	      (vector-scale! (copy p1) p2)
-	      (let* ((p1len (length p1))
-		     (p2len (length p2))
-		     (m (make-vector (+ p1len p2len) 0)))
-		(do ((i 0 (+ i 1)))
-		    ((= i p1len))
+	      (let ((p1len (length p1))
+		    (p2len (length p2)))
+		(do ((m (make-vector (+ p1len p2len) 0))
+		     (i 0 (+ i 1)))
+		    ((= i p1len) m)
 		  (do ((j 0 (+ j 1)))
 		      ((= j p2len))
-		    (set! (m (+ i j)) (+ (m (+ i j)) (* (p1 i) (p2 j))))))
-		m))))))
+		    (set! (m (+ i j)) (+ (m (+ i j)) (* (p1 i) (p2 j))))))))))))
 
 (define poly* 
   (let ((documentation "(poly* p1 p2) multiplies the polynomials (float-vectors or vectors) p1 and p2"))
@@ -176,9 +175,9 @@
 (define poly-as-vector-derivative 
   (let ((documentation "(poly-as-vector-derivative p1) returns the derivative or polynomial p1 (as a vector)"))
     (lambda (p1)
-      (let* ((len (- (length p1) 1))
-	     (v (make-vector len)))
-	(do ((i (- len 1) (- i 1))
+      (let ((len (- (length p1) 1)))
+	(do ((v (make-vector len))
+	     (i (- len 1) (- i 1))
 	     (j len (- j 1)))
 	    ((< i 0) v)
 	  (set! (v i) (* j (p1 j))))))))
@@ -197,23 +196,21 @@
 
 
 (define (submatrix mx row col)
-  (let* ((old-n (car (vector-dimensions mx)))
-	 (nmx (let ((new-n (- old-n 1)))
-		(make-float-vector (list new-n new-n)))))
-    (do ((i 0 (+ i 1))
+  (let ((old-n (car (vector-dimensions mx))))
+    (do ((nmx (let ((new-n (- old-n 1)))
+		(make-float-vector (list new-n new-n))))
+	 (i 0 (+ i 1))
 	 (ni 0))
-	((= i old-n))
-      (if (not (= i row))
-	  (begin
-	    (do ((j 0 (+ j 1))
-		 (nj 0))
-		((= j old-n))
-	      (if (not (= j col))
-		  (begin
-		    (set! (nmx ni nj) (mx i j))
-		    (set! nj (+ nj 1)))))
-	    (set! ni (+ 1 ni)))))
-    nmx))
+	((= i old-n) nmx)
+      (unless (= i row)
+	(do ((j 0 (+ j 1))
+	     (nj 0))
+	    ((= j old-n))
+	  (if (not (= j col))
+	      (begin
+		(set! (nmx ni nj) (mx i j))
+		(set! nj (+ nj 1)))))
+	(set! ni (+ 1 ni))))))
 
 (define (determinant mx)
   (if (not (float-vector? mx))
@@ -229,15 +226,14 @@
 		  (* (mx 0 1) (mx 1 0) (mx 2 2))
 		  (* (mx 0 2) (mx 1 1) (mx 2 0))))
 	  (else   
-	   (let ((sum 0.0)
-		 (sign 1))
-	     (do ((i 0 (+ i 1)))
-		 ((= i n))
-	       (let ((mult (mx 0 i)))
-		 (if (not (= mult 0.0))
-		     (set! sum (+ sum (* sign mult (determinant (submatrix mx 0 i))))))
-		 (set! sign (- sign))))
-	     sum))))))
+	   (do ((sum 0.0)
+		(sign 1)
+		(i 0 (+ i 1)))
+	       ((= i n) sum)
+	     (let ((mult (mx 0 i)))
+	       (if (not (= mult 0.0))
+		   (set! sum (+ sum (* sign mult (determinant (submatrix mx 0 i))))))
+	       (set! sign (- sign)))))))))
 
 (define (poly-as-vector-resultant p1 p2)
   (if (not (and (vector? p1)
@@ -419,13 +415,12 @@
 	   #f)))))
   
   (define (nth-roots a b deg) ; ax^n + b
-    (let ((n (expt (/ (- b) a) (/ 1.0 deg)))
-	  (incr (/ (* 2 pi 0+i) deg))
-	  (roots ()))
-      (do ((i 0 (+ i 1)))
-	  ((= i deg))
-	(set! roots (cons (simplify-complex (* n (exp (* i incr)))) roots)))
-      roots))
+    (do ((n (expt (/ (- b) a) (/ 1.0 deg)))
+	 (incr (/ (* 2 pi 0+i) deg))
+	 (roots ())
+	 (i 0 (+ i 1)))
+	((= i deg) roots)
+      (set! roots (cons (simplify-complex (* n (exp (* i incr)))) roots))))
   
   (let ((deg (- (length p1) 1)))
     
@@ -542,11 +537,11 @@
 	   (list 0.0))
 
 	  (else 
-	   (let ((pnew (make-vector deg)))
-		 (do ((i 1 (+ i 1)))
-		     ((> i deg))
-		   (set! (pnew (- i 1)) (p1 i)))
-		 (cons 0.0 (poly-as-vector-roots pnew)))))))
+	   (do ((pnew (make-vector deg))
+		(i 1 (+ i 1)))
+	       ((> i deg)
+		(cons 0.0 (poly-as-vector-roots pnew)))
+	     (set! (pnew (- i 1)) (p1 i)))))))
 
   
 (define poly-roots 
