@@ -45,9 +45,11 @@
 	  (apply #_make-hash-table args))))
 
 (define bytevector byte-vector)
-(define ->bytevector ->byte-vector)
+;(define ->bytevector string->byte-vector)
 (define bytevector? byte-vector?)
 (define make-bytevector make-byte-vector)
+(define bytevector-ref string-ref)
+(define bytevector-set! string-set!)
 
 (define bytevector-copy! vector-copy!)
 (define string-copy! vector-copy!)
@@ -104,8 +106,8 @@
 (define (bytevector-u8-set! b k c) (set! (b k) c))
 (define bytevector-u8 (dilambda (lambda (b k) (b k)) (lambda (b k c) (set! (b k) c))))
 (define bytevector-length length)
-(define (bytevector-copy . args) (->byte-vector (apply r7rs-string-copy args)))
-(define (bytevector-append . args) (->byte-vector (apply string-append args)))
+(define (bytevector-copy . args) (string->byte-vector (apply r7rs-string-copy args)))
+(define (bytevector-append . args) (string->byte-vector (apply string-append args)))
 (define write-bytevector write-string)
 (define* (read-bytevector! bv port (start 0) end)
   (let ((lim (or end (length bv)))
@@ -117,8 +119,8 @@
 	 bv)
       (set! (bv i) c))))
 (define* (read-bytevector k port)
-  (read-bytevector! (->byte-vector (make-string k)) port))
-(define (get-output-bytevector port) (->byte-vector (get-output-string port)))
+  (read-bytevector! (string->byte-vector (make-string k)) port))
+(define (get-output-bytevector port) (string->byte-vector (get-output-string port)))
 (define open-input-bytevector open-input-string)
 (define open-output-bytevector open-output-string)
 (define read-u8 read-byte)
@@ -126,7 +128,7 @@
 (define u8-ready? char-ready?) 
 (define peek-u8 peek-char)
 (define* (utf8->string v (start 0) end) (substring v start (or end (length v))))
-(define* (string->utf8 s (start 0) end) (->byte-vector (utf8->string s start end)))
+(define* (string->utf8 s (start 0) end) (string->byte-vector (utf8->string s start end)))
 (define write-simple write)
 
 (define (eof-object) #<eof>)
@@ -148,6 +150,7 @@
 
 
 (define interaction-environment curlet)
+;; for null-environment see stuff.scm
 (define-macro (include . files) 
   `(begin
      ,@(map (lambda (file)
