@@ -152,10 +152,8 @@
 	  (define* (write-history port (spaces 0))
 	    (format port "~NC(set! histpos ~D)~%" spaces #\space histpos)
 	    (format port "~NC(set! histsize ~D)~%" spaces #\space histsize)
-	    (let ((pl (*s7* 'print-length)))
-	      (set! (*s7* 'print-length) (* 2 histsize))
-	      (format port "~NC(set! histbuf ~A)" spaces #\space (object->string histbuf))
-	      (set! (*s7* 'print-length) pl)))
+	    (let-temporarily (((*s7* 'print-length) (* 2 histsize)))
+	      (format port "~NC(set! histbuf ~A)" spaces #\space histbuf)))
 	  
 	  (define* (save-history (file "repl-history.scm"))
 	    (call-with-output-file file
@@ -190,7 +188,7 @@
 	    (define (badexpr h)            ; *missing-close-paren-hook* function for Enter command
 	      (let ((ow (owlet)))
 		(if (ow 'error-file)
-		    (error "missing close paren in ~S" (ow 'error-file))
+		    (error 'syntax-error "missing close paren in ~S" (ow 'error-file))
 		    (set! (h 'result) 'string-read-error))))
 	    
 	    (define (shell? h)             ; *unbound-variable-hook* function, also for Enter
@@ -440,7 +438,7 @@
 	      ;; if a line wraps, it will confuse the redisplay/cursor positioning code. so truncate the display
 	      (let ((line-len (- (+ end prompt-length 1) start)))
 		(if (>= line-len last-col)
-		    (set! end (- (+ end line-len) last-col))))
+		    (set! end (- (+ start last-col) prompt-length 1))))
 	      
 	      (if (and (integer? red-par-pos)
 		       (<= start red-par-pos)
@@ -462,27 +460,27 @@
 				 (values "~NC~A" prompt-length #\space (substring cur-line start end))))))
 	    
 	    (define (display-cursor)
-	      (let ((row 0)
-		    (start 0)
-		    (len (length cur-line)))
-		(do ((i 0 (+ i 1)))
-		    ((or (= i len)
-			 (= i cursor-pos))
-		     (move-cursor (+ prompt-row row) (- (+ prompt-col cursor-pos) start)))
-		  (when (char=? (cur-line i) #\newline)
-		    (set! row (+ row 1))
-		    (set! start (+ i 1))))))
+	      (do ((row 0)
+		   (start 0)
+		   (len (length cur-line))
+		   (i 0 (+ i 1)))
+		  ((or (= i len)
+		       (= i cursor-pos))
+		   (move-cursor (+ prompt-row row) (- (+ prompt-col cursor-pos) start)))
+		(when (char=? (cur-line i) #\newline)
+		  (set! row (+ row 1))
+		  (set! start (+ i 1)))))
 	    
 	    (define (display-lines)
 	      (move-cursor prompt-row 0)
 	      (format *stderr* "~C[J" #\escape)
 	      (let ((len (length cur-line))
 		    (new-line ""))
-		(let ((line-end 0))
-		  (do ((i 0 (+ line-end 2)))
-		      ((> i len))
-		    (set! line-end (end-of-line i))
-		    (set! new-line (string-append new-line (display-line i (min (+ line-end 2) len))))))
+		(do ((line-end 0)
+		     (i 0 (+ line-end 2)))
+		    ((> i len))
+		  (set! line-end (end-of-line i))
+		  (set! new-line (string-append new-line (display-line i (min (+ line-end 2) len)))))
 		(format *stderr* "~A" new-line)
 		(display-cursor)))
 	    
@@ -519,13 +517,13 @@
 	      (set! (*repl* 'helpers)
 		    (list
 		     (lambda (c) 
-		       (format #f "cursor: ~A, ~C, line: ~S"
-			       cursor-pos
-			       (if (zero? (length cur-line))
-				   #\space
-				   (let ((c (cur-line (max 0 (min cursor-pos (- (length cur-line) 1))))))
-				     (if (char=? c #\newline) #\| c)))
-			       (one-line cur-line)))
+		       (let ((cur-char (if (zero? (length cur-line))
+					   #\space
+					   (let ((c (cur-line (max 0 (min cursor-pos (- (length cur-line) 1))))))
+					     (if (char=? c #\newline) #\| c)))))
+			 (format #f "cursor: ~A, ~C, line: ~S"
+				 cursor-pos cur-char
+				 (one-line cur-line))))
 		     (lambda (c)
 		       (format #f "len: ~D, selection: ~S, previous: ~S" 
 			       (length cur-line) 
@@ -537,7 +535,7 @@
 			       prompt-row))
 		     (lambda (c)
 		       (format #f "c: ~S ~D, start: ~A, end: ~A" 
-			       (object->string c #t) 
+			       c
 			       (char->integer c)	
 			       (start-of-line cursor-pos)	
 			       (end-of-line cursor-pos))))))
@@ -619,13 +617,12 @@
 	      (set! cur-row (+ cur-row 1)))
 	    
 	    (define (word-break pos)                 ; assume we're at the start of a word
-	      (let ((len (length cur-line)))
-		(let loop ((i pos))
-		  (if (or (>= i len)
-			  (not (or (char-alphabetic? (cur-line i))
-				   (char-numeric? (cur-line i)))))
-		      i
-		      (loop (+ i 1))))))
+	      (do ((len (length cur-line))
+		   (i pos (+ i 1)))
+		  ((or (>= i len) 
+		       (not (or (char-alphabetic? (cur-line i)) 
+				(char-numeric? (cur-line i)))))
+		   i)))
 	    
 	    (define (save-line)
 	      (set! prev-line (cons (cons cursor-pos (copy cur-line)) prev-line)))
@@ -945,12 +942,12 @@
 
 	      (define (fixup-new-line)
 		(define (count-newlines line)
-		  (let ((len (length line))
-			(newlines 0))
-		    (do ((i 0 (+ i 1)))
-			((= i len) newlines)
-		      (if (char=? (cur-line i) #\newline)
-			  (set! newlines (+ newlines 1))))))
+		  (do ((len (length line))
+		       (newlines 0)
+		       (i 0 (+ i 1)))
+		      ((= i len) newlines)
+		    (if (char=? (cur-line i) #\newline)
+			(set! newlines (+ newlines 1)))))
 		(set! cursor-pos (length cur-line))
 		(let ((newlines (count-newlines cur-line)))
 		  (when (< last-row (+ prompt-row newlines))
@@ -1004,30 +1001,30 @@
 			      (loop (+ i 1)))))))
 		
 		(define (upper-case c)
-		  (let ((len (length cur-line)))
-		    (do ((i cursor-pos (+ i 1)))
-			((or (= i len)
-			     (char-alphabetic? (cur-line i)))
-			 (when (< i len)
-			   (save-line)
-			   (do ((k i (+ k 1)))
-			       ((or (= k len)
-				    (not (char-alphabetic? (cur-line k))))
-				(set! cursor-pos k))
-			     (set! (cur-line k) (char-upcase (cur-line k)))))))))
+		  (do ((len (length cur-line))
+		       (i cursor-pos (+ i 1)))
+		      ((or (= i len)
+			   (char-alphabetic? (cur-line i)))
+		       (when (< i len)
+			 (save-line)
+			 (do ((k i (+ k 1)))
+			     ((or (= k len)
+				  (not (char-alphabetic? (cur-line k))))
+			      (set! cursor-pos k))
+			   (set! (cur-line k) (char-upcase (cur-line k))))))))
 	    
 		(define (lower-case c)
-		  (let ((len (length cur-line)))
-		    (do ((i cursor-pos (+ i 1)))
-			((or (= i len)
-			     (char-alphabetic? (cur-line i)))
-			 (when (< i len)
-			   (save-line)
-			   (do ((k i (+ k 1)))
-			       ((or (= k len)
-				    (not (char-alphabetic? (cur-line k))))
-				(set! cursor-pos k))
-			     (set! (cur-line k) (char-downcase (cur-line k)))))))))
+		  (do ((len (length cur-line))
+		       (i cursor-pos (+ i 1)))
+		      ((or (= i len)
+			   (char-alphabetic? (cur-line i)))
+		       (when (< i len)
+			 (save-line)
+			 (do ((k i (+ k 1)))
+			     ((or (= k len)
+				  (not (char-alphabetic? (cur-line k))))
+			      (set! cursor-pos k))
+			   (set! (cur-line k) (char-downcase (cur-line k))))))))
 		
 		(set! (meta-keymap-functions (char->integer #\p)) move-backward-in-history)
 		(set! (meta-keymap-functions (char->integer #\n)) move-forward-in-history)
@@ -1092,75 +1089,82 @@
 			    (lambda ()
 			      (call-with-exit
 			       (lambda (return)
+				 
+				 ;; if (< ctr chars), just send the next char in the buffer (90 lines down after (return #\null))
+				 ;;   otherwise call read again
 				 (when (>= ctr chars)
 				   (set! ctr 0)
 				   (set! chars (read input-fd cc read-size))
 				   (if (= chars 0)
 				       (tty-reset))
-				   
-				   (when (= chars read-size)
-				     ;; concatenate buffers until we get the entire selection
-				     (let ((str (substring c 0 read-size)))
-				       (let reading ((num (read input-fd cc read-size)))
-					 (set! str (string-append str (substring c 0 num)))
-					 (set! chars (+ chars num))
-					 (if (= num read-size)
-					     (reading (read input-fd cc read-size))))
+
+				   (when (> chars (- last-col prompt-length 12))
+				     (let ((str (substring c 0 chars)))
+
+				       (when (= chars read-size)
+					 ;; concatenate buffers until we get the entire selection
+					 (let reading ((num (read input-fd cc read-size)))
+					   (set! str (string-append str (substring c 0 num)))
+					   (set! chars (+ chars num))
+					   (if (= num read-size)
+					       (reading (read input-fd cc read-size)))))
 				       
 				       ;; look for simple cut/paste -- no control chars etc
 				       (when (= input-fd terminal-fd)
-					 (let ((bcksp #\delete)
-					       (ok-chars (list #\newline #\linefeed #\return #\tab)))
-					   (do ((i 0 (+ i 1)))
-					       ((or (= i chars)
-						    (char>=? (str i) bcksp)
-						    (and (char<? (str i) #\space)
-							 (not (memv (str i) ok-chars))))
+					 (do ((bcksp #\delete)
+					      (ok-chars (list #\newline #\linefeed #\return #\tab))
+					      (i 0 (+ i 1)))
+					     ((or (= i chars)
+						  (char>=? (str i) bcksp)
+						  (and (char<? (str i) #\space)
+						       (not (memv (str i) ok-chars))))
+					      
+					      (when (= i chars)
+						(let ((search-chars (string #\tab #\return #\newline))
+						      (old-pos 0)
+						      (start 0)
+						      (max-cols 0))
+						  (do ((pos (char-position search-chars str 0) (char-position search-chars str (+ pos 1))))
+						      ((not pos))
+						    (set! cur-line (string-append cur-line 
+										  (substring str old-pos pos)
+										  (if (char=? (str pos) #\tab) 
+										      tab-as-space 
+										      (string #\space #\newline))))
+						    (set! old-pos (+ pos 1))
+						    (unless (char=? (str pos) #\tab)
+						      (set! max-cols (max max-cols (- pos start)))
+						      (set! start pos)))
+						  (if (< (+ old-pos 1) (length str))
+						      (set! cur-line (string-append cur-line (substring str (+ old-pos 1)))))
+						  
+						  ;; if the line is too long, the cursor gets confused, so try to reformat long strings
+						  ;;    this still messes up sometimes
+						  (when (> max-cols (- last-col prompt-length))
+						    (let-temporarily ((((funclet pretty-print) '*pretty-print-length*) (- last-col prompt-length 12)))
+						      (set! ((funclet pretty-print) '*pretty-print-length*) (- last-col prompt-length 12))
+						      (set! cur-line (with-output-to-string
+								       (lambda ()
+									 (pretty-print (with-input-from-string cur-line #_read))))))))
+						;; this is still bad if the code has a long string -- need to tell pretty print to break it as well
 						
-						(when (= i chars)
-						  (let ((search-chars (string #\tab #\return #\newline))
-							(old-pos 0)
-							(start 0)
-							(max-cols 0))
-						    (do ((pos (char-position search-chars str 0) (char-position search-chars str (+ pos 1))))
-							((not pos))
-						      (set! cur-line (string-append cur-line 
-										    (substring str old-pos pos)
-										    (if (char=? (str pos) #\tab) 
-											tab-as-space 
-											(string #\space #\newline))))
-						      (set! old-pos (+ pos 1))
-						      (unless (char=? (str pos) #\tab)
-							(set! max-cols (max max-cols (- pos start)))
-							(set! start pos)))
-						    (if (< (+ old-pos 1) (length str))
-							(set! cur-line (string-append cur-line (substring str (+ old-pos 1)))))
-						    
-						    ;; if the line is too long, the cursor gets confused, so try to reformat over-long strings
-						    ;; this still messes up sometimes
-						    
-						    (when (> max-cols (- last-col prompt-length))
-						      (let ((old-len ((funclet pretty-print) '*pretty-print-length*)))
-							(set! ((funclet pretty-print) '*pretty-print-length*) (- last-col prompt-length 2))
-							(set! cur-line (with-output-to-string
-									 (lambda ()
-									   (pretty-print (with-input-from-string cur-line #_read)))))
-							(set! ((funclet pretty-print) '*pretty-print-length*) old-len))))
-						    
-						  (set! cursor-pos (length cur-line))
-						  (set! chars 0)
-						  (set! ctr 1)
-						  (display-lines)
-						  (return #\newline))))))
-				       
+						(set! cursor-pos (length cur-line))
+						(set! chars 0)
+						(set! ctr 1)
+						(display-lines)
+						(return #\newline)))))
+				       ;; now the pasted-in line has inserted newlines, we hope
+
 				       (set! c str)
 				       (set! cc (string->c-pointer c))
+
 				       ;; avoid time-consuming redisplays.  We need to use a recursive call on next-char here
 				       ;;   since we might have multi-char commands (embedded #\escape -> meta, etc)
 				       ;; actually, the time is not the repl's fault -- xterm seems to be waiting
 				       ;;   for the window manager or someone to poke it -- if I move the mouse,
 				       ;;   I get immediate output.  I also get immediate output in any case in OSX.
 				       ;;   valgrind and ps say we're not computing, we're just sitting there.
+
 				       (catch #t
 					 (lambda ()
 					   (do ((ch (next-char) (next-char)))
@@ -1181,6 +1185,7 @@
 					   (new-prompt)
 					   (return #\null))))))
 				 
+				 ;; send out the next char
 				 (let ((result (c ctr)))
 				   (set! ctr (+ ctr 1))
 				   result)))))))
@@ -1349,8 +1354,9 @@
 			  ((> j L1))
 			(let ((c1 (+ (distance i (- j 1)) 1))
 			      (c2 (+ (distance (- i 1) j) 1))
-			      (c3 (+ (distance (- i 1) (- j 1)) 
-				     (if (char=? (s2 (- i 1)) (s1 (- j 1))) 0 1))))
+			      (c3 (if (char=? (s2 (- i 1)) (s1 (- j 1)))
+				      (distance (- i 1) (- j 1))
+				      (+ (distance (- i 1) (- j 1)) 1))))
 			  (set! (distance i j) (min c1 c2 c3)))))
 		    (distance L2 L1))))))
 
@@ -1410,6 +1416,66 @@
 	    '----)))))
 
 
+
+;;; --------------------------------------------------------------------------------
+;;; just a first stab at this -- where to put this code?
+;;;
+;;; debug-help can be set running via: (((*repl* 'repl-let) 'debug-help))
+
+(define-expansion (repl-debug)
+  `(with-let (inlet :orig (curlet) :line ,(port-line-number) :func __func__)
+     (format () "line ~D: ~A~{~^ ~A~}~%" 
+	     line (if (pair? func) (car func) func)
+	     (reverse
+	      (map (lambda (slot)
+		     (format #f "~%    ~S: ~A" 
+			     (car slot) 
+			     (let ((val (object->string (cdr slot) #f)))
+			       (if (> (length val) 60)
+				   (string-append (substring val 0 60) "...")
+				   val))))
+		   orig)))
+
+     (let ((C-q (integer->char 17)))
+       (let ((old-C-q ((*repl* 'keymap) C-q))
+	     (old-top-level (*repl* 'top-level-let))
+	     (old-prompt-string ((*repl* 'repl-let) 'prompt-string))
+	     (old-prompt (*repl* 'prompt)))
+
+	 (dynamic-wind
+	     (lambda ()
+	       (set! (*repl* 'top-level-let) orig)
+	       (with-let (*repl* 'repl-let)
+		 (set! cur-line "")
+		 (set! red-par-pos #f)
+		 (set! cursor-pos 0)
+		 (set! prompt-string (format #f "<debug ~D> " (+ (length histtop) 1)))
+		 (set! prompt-length (length prompt-string)))
+	       (with-let *repl*
+		 (set! prompt (lambda (num) 
+				(with-let (sublet repl-let :num num)
+				  (set! prompt-string (format #f "<debug ~D> " num))
+				  (set! prompt-length (length prompt-string)))))
+		 (set! (keymap (integer->char 17))
+		       (lambda (c)
+			 (set! (repl-let 'all-done) #t)))))
+
+	     (lambda ()
+	       ((*repl* 'run)))
+
+	     (lambda ()
+	       (set! (*repl* 'top-level-let) old-top-level)
+	       (set! ((*repl* 'repl-let) 'prompt-string) old-prompt)
+	       (set! ((*repl* 'repl-let) 'prompt-length) (length old-prompt))
+	       (set! (*repl* 'prompt) old-prompt)
+	       (set! ((*repl* 'keymap) C-q) old-C-q)))))))
+
+
+;;; to display a variable's value as s7 runs using the repl help window:
+;;;    (define xyz 1) ; some variable...
+;;;    (set! (symbol-access 'xyz) (lambda (sym val) (set! (*repl* 'helpers) (list (lambda (c) (format #f "xyz: ~S" val)))) val))
+
+
 ;;; --------------------------------------------------------------------------------
 #|
 to work in a particular environment:
@@ -1498,10 +1564,10 @@ to post a help string (kinda tedious, but the helper list is aimed more at posti
 		    (old-cursor-pos cursor-pos)
 		    (old-enter-func (keymap-functions 10))
 		    (filename #f))
-		(set! (*repl 'prompt) (lambda (num) 
-					(with-let (*repl* 'repl-let)
-					  (set! prompt-string "load: ")
-					  (set! prompt-length 6))))
+		(set! (*repl* 'prompt) (lambda (num) 
+					 (with-let (*repl* 'repl-let)
+					   (set! prompt-string "load: ")
+					   (set! prompt-length 6))))
 		(set! cur-line "")
 		(set! cursor-pos 0)
 		(set! (keymap-functions 10) (lambda (c)
