@@ -6,6 +6,9 @@
 ;;; S7 is embedded in Snd or Sndlib;
 ;;; It does not exist as a stand-alone program.
 
+;;@ define an error procedure for the library
+(define slib:error error)
+
 ;;@ (software-type) should be set to the generic operating system type.
 ;;; unix, vms, macos, amiga and ms-dos are supported.
 (define (software-type) 'unix)
@@ -100,12 +103,12 @@
 (define sub-vicinity
   (if (eq? (software-type) 'vms)
       (lambda (vic name)
-	(let ((L (string-length vic)))
+	(let ((L (- (string-length vic) 1)))
 	  (string-append
 	   (if (or (string=? vic "")
-		   (not (char=? #\] (string-ref vic (- L 1)))))
+		   (not (char=? #\] (string-ref vic L))))
 	       (values vic "[")
-	       (values (substring vic 0 (- L 1)) "."))
+	       (values (substring vic 0 L) "."))
 	   name "]")))
       (let ((*vicinity-suffix* (case (software-type)
 				 ((nosve) ".")
@@ -321,9 +324,6 @@
       (if (provided? 'trace) (print-call-stack cep))
       (format cep "Warn: ~{ ~S~}~%" args))))
 
-;;@ define an error procedure for the library
-(define slib:error error)
-
 ;@
 (define (make-exchanger obj)
   (lambda (rep) (let ((old obj)) (set! obj rep) old)))
@@ -361,7 +361,9 @@
 (define slib:form-feed #\xc) ;(integer->char 12))
 
 ;;@ Support for older versions of Scheme.  Not enough code for its own file.
-(define (last-pair lst) (if (pair? (cdr lst)) (last-pair (cdr lst)) lst))
+;(define (last-pair lst) (if (pair? (cdr lst)) (last-pair (cdr lst)) lst))
+(define (last-pair lst) (do ((lst lst (cdr lst))) ((not (pair? (cdr lst))) lst)))
+
 (define t #t)
 (define nil #f)
 
