@@ -1569,7 +1569,7 @@ x0 y0 x1 y1 xmin ymin xmax ymax pix_x0 pix_y0 pix_x1 pix_y1 y_offset xscale ysca
   Snd_assert_channel(S_axis_info, snd, chn, 1);
   Xen_check_type(Xen_is_integer_or_unbound(ap_id), ap_id, 3, S_axis_info, S_time_graph ", " S_transform_graph ", or " S_lisp_graph);
   ap = TO_C_AXIS_INFO(snd, chn, ap_id, S_axis_info);
-  if (ap == NULL) return(Xen_empty_list);
+  if (!ap) return(Xen_empty_list);
   return(Xen_cons(C_llong_to_Xen_llong(ap->losamp),
 	  Xen_cons(C_llong_to_Xen_llong(ap->hisamp),
 	   Xen_cons(C_double_to_Xen_real(ap->x0),
@@ -1933,7 +1933,6 @@ static Xen g_set_y_bounds(Xen bounds, Xen snd, Xen chn, Xen ax)
   chan_info *cp;
   axis_info *ap;
   mus_float_t low = 0.0, hi = 0.0;
-  Xen y0 = Xen_undefined, y1 = Xen_undefined;
 
   Snd_assert_channel(S_set S_y_bounds, snd, chn, 2);
   Xen_check_type((Xen_is_number(bounds)) || (Xen_is_list(bounds)), bounds, 1, S_set S_y_bounds, "a list or a number");
@@ -1951,6 +1950,7 @@ static Xen g_set_y_bounds(Xen bounds, Xen snd, Xen chn, Xen ax)
   else
     {
       int len;
+      Xen y0 = Xen_undefined, y1 = Xen_undefined;
       len = Xen_list_length(bounds);
       if (len > 0)
 	{
