@@ -95,16 +95,16 @@
 
 
 ;;; ----------------
-(define (first obj)  (if (sequence? obj) (obj 0) (error "first argument, ~S, is not a sequence" obj)))
-(define (second obj) (if (sequence? obj) (obj 1) (error "second argument, ~S, is not a sequence" obj)))
-(define (third obj)  (if (sequence? obj) (obj 2) (error "third argument, ~S, is not a sequence" obj)))
-(define (fourth obj) (if (sequence? obj) (obj 3) (error "fourth argument, ~S, is not a sequence" obj)))
-(define (fifth obj)  (if (sequence? obj) (obj 4) (error "fifth argument, ~S, is not a sequence" obj)))
-(define (sixth obj)  (if (sequence? obj) (obj 5) (error "sixth argument, ~S, is not a sequence" obj)))
-(define (seventh obj)(if (sequence? obj) (obj 6) (error "seventh argument, ~S, is not a sequence" obj)))
-(define (eighth obj) (if (sequence? obj) (obj 7) (error "eighthment, ~S, is not a sequence" obj)))
-(define (ninth obj)  (if (sequence? obj) (obj 8) (error "ninth argument, ~S, is not a sequence" obj)))
-(define (tenth obj)  (if (sequence? obj) (obj 9) (error "tenth argument, ~S, is not a sequence" obj)))
+(define (first obj)  (if (sequence? obj) (obj 0) (error 'wrong-type-arg "first argument, ~S, is not a sequence" obj)))
+(define (second obj) (if (sequence? obj) (obj 1) (error 'wrong-type-arg "second argument, ~S, is not a sequence" obj)))
+(define (third obj)  (if (sequence? obj) (obj 2) (error 'wrong-type-arg "third argument, ~S, is not a sequence" obj)))
+(define (fourth obj) (if (sequence? obj) (obj 3) (error 'wrong-type-arg "fourth argument, ~S, is not a sequence" obj)))
+(define (fifth obj)  (if (sequence? obj) (obj 4) (error 'wrong-type-arg "fifth argument, ~S, is not a sequence" obj)))
+(define (sixth obj)  (if (sequence? obj) (obj 5) (error 'wrong-type-arg "sixth argument, ~S, is not a sequence" obj)))
+(define (seventh obj)(if (sequence? obj) (obj 6) (error 'wrong-type-arg "seventh argument, ~S, is not a sequence" obj)))
+(define (eighth obj) (if (sequence? obj) (obj 7) (error 'wrong-type-arg "eighthment, ~S, is not a sequence" obj)))
+(define (ninth obj)  (if (sequence? obj) (obj 8) (error 'wrong-type-arg "ninth argument, ~S, is not a sequence" obj)))
+(define (tenth obj)  (if (sequence? obj) (obj 9) (error 'wrong-type-arg "tenth argument, ~S, is not a sequence" obj)))
 
 
 (define iota 
@@ -202,8 +202,8 @@
 	    ,@body)
 	  ,expr))
       (if (and (null? vars) (null? expr))
-	  `(begin ,@body)
-	  (error "multiple-value-set! vars/exprs messed up"))))
+	  (cons 'begin body)
+	  (error 'syntax-error "multiple-value-set! vars/exprs messed up"))))
 
 
 
@@ -287,14 +287,15 @@
   `(for-each define ',args (iota (length ',args))))
 
 (define-macro (destructuring-bind lst expr . body) ; if only there were some use for this!
-  `(let ,(let flatten ((lst1 lst)
-		       (lst2 (eval expr))
-		       (args ()))
-	   (cond ((null? lst1) args)
-		 ((not (pair? lst1)) (cons (list lst1 lst2) args))
-		 (else (flatten (car lst1) (car lst2) 
-				(flatten (cdr lst1) (cdr lst2) args)))))
-     ,@body))
+  (cons 'let 
+	(cons (let flatten ((lst1 lst)
+			    (lst2 (eval expr))
+			    (args ()))
+		(cond ((null? lst1) args)
+		      ((not (pair? lst1)) (cons (list lst1 lst2) args))
+		      (else (flatten (car lst1) (car lst2) 
+				     (flatten (cdr lst1) (cdr lst2) args)))))
+	      body)))
 
 #|
 ;; kinda ugly!
@@ -327,27 +328,7 @@
 			  `(set! (with-let orig ,(car v)) (list-ref saved ,(set! ctr (+ ctr 1)))))))
 		  vars)))))
 
-(define-macro (let-temporarily vars . body)
-  `(with-let (#_inlet :orig (#_curlet) 
-		      :saved (#_list ,@(map car vars))
-		      :new (#_list ,@(map cadr vars)))
-     (dynamic-wind
-	 (lambda () #f)
-	 (lambda () ; this could be (with-let orig (let ,vars ,@body)) but I want to handle stuff like individual vector locations
-	   ,@(map (let ((ctr -1))
-		    (lambda (v)
-		      (if (symbol? (car v))
-			  `(set! (orig ',(car v)) (list-ref new ,(set! ctr (+ ctr 1))))
-			  `(set! (with-let orig ,(car v)) (list-ref new ,(set! ctr (+ ctr 1)))))))
-		    vars)
-	   (with-let orig ,@body)) 
-	 (lambda ()
-	   ,@(map (let ((ctr -1))
-		    (lambda (v)
-		      (if (symbol? (car v))
-			  `(set! (orig ',(car v)) (list-ref saved ,(set! ctr (+ ctr 1))))
-			  `(set! (with-let orig ,(car v)) (list-ref saved ,(set! ctr (+ ctr 1)))))))
-		  vars)))))
+;;; 14-8-16: moved let-temporarily to s7.c
 
 (define-macro (while test . body)      ; while loop with predefined break and continue
   `(call-with-exit
@@ -372,12 +353,13 @@
 	      spec))))
 
 (define-macro (string-case selector . clauses)
-  `(case (symbol ,selector)             ; case with string constant keys
-     ,@(map (lambda (clause)
-	      (if (pair? (car clause))
-		  `(,(map symbol (car clause)) ,@(cdr clause))
-		  clause))
-	    clauses)))
+  (cons 'case       ; case with string constant keys
+	(cons (list 'symbol selector)
+	      (map (lambda (clause)
+		     (if (pair? (car clause))
+			 (cons (map symbol (car clause)) (cdr clause))
+			 clause))
+		   clauses))))
 
 (define-macro (eval-case key . clauses) ; case with evaluated key-lists
   (let ((select (gensym)))
@@ -398,7 +380,7 @@
     (lambda (table)
       (if (hash-table? table)
 	  (map values table)
-	  (error "hash-table->alist argument, ~A, is not a hash-table" table)))))
+	  (error 'wrong-type-arg "hash-table->alist argument, ~A, is not a hash-table" table)))))
 
 (define merge-hash-tables 
   (let ((documentation "(merge-hash-tables . tables) returns a new hash-table with the contents of all the tables"))
@@ -533,8 +515,8 @@ If func approves of one, index-if returns the index that gives that element's po
 			  (if (sequence? x) (full-find-if-1 x))))
 		    seq))
 		 #f))
-	      (error "full-find-if second argument, ~A, is not a sequence" sequence))
-	  (error "full-find-if first argument, ~A, is not a procedure of one argument" f)))))
+	      (error 'wrong-type-arg "full-find-if second argument, ~A, is not a sequence" sequence))
+	  (error 'wrong-type-arg "full-find-if first argument, ~A, is not a procedure of one argument" f)))))
 
 (define full-count-if 
   (let ((documentation "(full-count-if func sequence) searches sequence, and recursively any sequences it contains, returning the number of elements that satisfy func"))
@@ -572,41 +554,41 @@ If func approves of one, index-if returns the index that gives that element's po
 
 
 (define (make-complete-iterator obj)
-  (make-iterator
-   (let ((iters ())
-	 (cycles (cyclic-sequences obj))
-	 (seen-cycles ()))
-
-     (define (make-careful-iterator p)
-       (if (not (pair? p))
-	   (make-iterator p)
-	   (let ((len (length p)))
-	     (make-iterator
-	      (cond ((infinite? len)      ; circular list
-		     (let ((cur p)
-			   (iterator? #t))
-		       (lambda ()
-			 (if (memq cur seen-cycles)
-			     #<eof>
-			     (let ((result (car cur)))
-			       (if (memq cur cycles) 
-				   (set! seen-cycles (cons cur seen-cycles)))
-			       (set! cur (cdr cur))
-			       result)))))
-		    ((positive? len)      ; normal list
-		     p)
-		    (else 
-		     (let ((cur p)        ; dotted list
-			   (iterator? #t))
-		       (lambda ()
-			 (if (pair? cur)
-			     (let ((result (car cur)))
-			       (set! cur (cdr cur))
-			       result)
-			     (let ((result cur))
-			       (set! cur #<eof>)
-			       result))))))))))
-
+  (let ((iters ())
+	(cycles (cyclic-sequences obj))
+	(seen-cycles ()))
+    
+    (define (make-careful-iterator p)
+      (if (not (pair? p))
+	  (make-iterator p)
+	  (let ((len (length p)))
+	    (make-iterator
+	     (cond ((infinite? len)      ; circular list
+		    (let ((cur p)
+			  (iterator? #t))
+		      (lambda ()
+			(if (memq cur seen-cycles)
+			    #<eof>
+			    (let ((result (car cur)))
+			      (if (memq cur cycles) 
+				  (set! seen-cycles (cons cur seen-cycles)))
+			      (set! cur (cdr cur))
+			      result)))))
+		   ((positive? len)      ; normal list
+		    p)
+		   (else 
+		    (let ((cur p)        ; dotted list
+			  (iterator? #t))
+		      (lambda ()
+			(if (pair? cur)
+			    (let ((result (car cur)))
+			      (set! cur (cdr cur))
+			      result)
+			    (let ((result cur))
+			      (set! cur #<eof>)
+			      result))))))))))
+    
+    (make-iterator
      (let ((iter (make-careful-iterator obj))
 	   (iterator? #t))       
        (define (iterloop) ; define returns the new value
@@ -658,8 +640,8 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	  (let ((count 0))
 	    (safe-find-if (lambda (x) (if (f x) (set! count (+ count 1))) #f) sequence)
 	    count)
-	  (error "safe-count-if first argument, ~A, should be a function" f))
-      (error "safe-count-if second argument, ~A, should be a sequence" sequence)))
+	  (error 'wrong-type-arg "safe-count-if first argument, ~A, should be a function" f))
+      (error 'wrong-type-arg "safe-count-if second argument, ~A, should be a sequence" sequence)))
 
 
 
@@ -694,7 +676,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 					    (set! lst (cons obj lst))))
 				      (car sequences)))
 			(reverse lst)))
-	  (error "intersection arguments should be sequences: ~A" sequences)))))
+	  (error 'wrong-type-arg "intersection arguments should be sequences: ~A" sequences)))))
   
 (define union 
   (let ((documentation "(union type . sequences) returns via type the union of the sequences:\n\
@@ -789,7 +771,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	       (aritable? p 1))
 	  (let ((e (funclet ->predicate)))
 	    (set! (e 'predicates) (cons p (e 'predicates))))
-	  (error "add-predicate argument, ~A, is not a procedure of one argument" p)))))
+	  (error 'wrong-type-arg "add-predicate argument, ~A, is not a procedure of one argument" p)))))
 
 (define typeq? 
   (let ((documentation "(typeq? . objs) returns #t if all objs have the same type (as determined by ->predicate)"))
@@ -807,7 +789,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 			  (if (= (length (car clause)) 1)
 			      `((,(caar clause) ,obj) ,@(cdr clause))
 			      `((or ,@(map (lambda (type)
-					     `(,type ,obj))
+					     (list type obj))
 					   (car clause)))
 				,@(cdr clause)))))
 		    clauses)))))
@@ -833,9 +815,9 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
   (lognot (apply logior ints)))
 
 (define (logeqv . ints)
-  (if (odd? (length ints))
-      (lognot (apply logxor -1 ints)) ; Clisp does it this way
-      (lognot (apply logxor ints))))
+  (lognot (apply logxor (if (odd? (length ints))
+			    (values -1 ints) ; Clisp does it this way
+			    ints))))
 
 (define (log-none-of . ints)  ; bits on in none of ints
   (lognot (apply logior ints)))
@@ -845,9 +827,9 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 
 (define (log-n-of n . ints)   ; return the bits on in exactly n of ints
   (if (not (integer? n))
-      (error "log-n-of first argument, ~A, should be an integer" n)
+      (error 'wrong-type-arg "log-n-of first argument, ~A, should be an integer" n)
       (if (not (every? integer? ints))
-	  (error "log-n-of ints arguments, ~A, should all be integers" ints)
+	  (error 'wrong-type-arg "log-n-of ints arguments, ~A, should all be integers" ints)
 	  (let ((len (length ints)))
 	    (cond ((= len 0) (if (= n 0) -1 0))
 		  ((= n 0)   (lognot (apply logior ints)))
@@ -999,7 +981,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
        (let ((gf ((car args) ',name))) ; get local definition
 	 (if (not (eq? gf ,name))      ; avoid infinite recursion
              (apply gf args)
-	     (error "attempt to call generic function wrapper recursively"))))))
+	     (error 'syntax-error "attempt to call generic function wrapper recursively"))))))
 
 (define-macro (define-slot-accessor name slot)
   `(define ,name (dilambda 
@@ -1053,7 +1035,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 		 (set! methods (cons next-method methods)))))
 	 (obj 'inherited))
 	(reverse methods))
-      (error "all-methods 'method argument should be a symbol: ~A" method)))
+      (error 'wrong-type-arg "all-methods 'method argument should be a symbol: ~A" method)))
 
 
 
@@ -1104,18 +1086,18 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
   (let ((documentation "(n-choose-k n k) returns the binomial coefficient C(N,K)"))
     (lambda (n k)
       (if (not (integer? n))
-	  (error "n-choose-k 'n argument, ~A, should be an integer" n)
+	  (error 'wrong-type-arg "n-choose-k 'n argument, ~A, should be an integer" n)
 	  (if (not (integer? k))
-	      (error "n-choose-k 'k argument, ~A, should be an integer" k)
+	      (error 'wrong-type-arg "n-choose-k 'k argument, ~A, should be an integer" k)
 	      (let ((mn (min k (- n k))))
 		(if (or (negative? mn)
 			(negative? n))
 		    0
 		    (if (= mn 0)
 			1
-			(let* ((mx (max k (- n k)))
-			       (cnk (+ 1 mx)))
-			  (do ((i 2 (+ i 1)))
+			(let ((mx (max k (- n k))))
+			  (do ((cnk (+ 1 mx))
+			       (i 2 (+ i 1)))
 			      ((> i mn) cnk)
 			    (set! cnk (/ (* cnk (+ mx i)) i))))))))))))
 	      
@@ -1140,7 +1122,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	(proc (openlet
 	       (inlet 'read (lambda (p)
 			      (v (set! i (+ i 1))))))))
-      (error "call-with-input-vector first argument, ~A, should be a vector" v)))
+      (error 'wrong-type-arg "call-with-input-vector first argument, ~A, should be a vector" v)))
 
 (define (call-with-output-vector proc)
   (let* ((size 1)
@@ -1169,7 +1151,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 
 (define* (flatten-let e (n -1))
   (if (not (let? e))
-      (error "flatten-let argument, ~A, is not a let" e)
+      (error 'wrong-type-arg "flatten-let argument, ~A, is not a let" e)
       (do ((slots ())
 	   (pe e (outlet pe))
 	   (i 0 (+ i 1)))
@@ -1216,7 +1198,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
     (for-each (lambda (var)
 		(format *stderr* "~S: ~S~%" (car var) (cdr var)))
 	      e)
-    `(begin ,@body)))
+    (cons 'begin body)))
 
 ;; now (let ((a 1) (b 2)) (list (set! a 3) (reflective-probe b))) -> '(3 2)
 ;; and (let ((a 1) (b 2)) (list (set! a 3) (reflective-probe) b)) -> '(3 () 2)
@@ -1473,7 +1455,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
     (if (pair? v)
 	`(reactive-let ((,(caar v) ,(cadar v)))
 	   ,(add-let (cdr v)))
-	`(begin ,@body))))
+	(cons 'begin body))))
 
 ;; reactive-letrec is not useful: lambdas already react and anything else is an error (use of #<undefined>)
 
@@ -1657,23 +1639,22 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	   (cdr* obj start))
 
           (else
-           (let ((lst (make-list new-len #f)))
-             (do ((i 0 (+ i 1)))
-                 ((= i new-len) lst)
-               (set! (lst i) (obj (+ i start)))))))))
+           (do ((lst (make-list new-len #f))
+		(i 0 (+ i 1)))
+	       ((= i new-len) lst)
+	     (set! (lst i) (obj (+ i start))))))))
 
 
 (define (sequence->string val)
-  (format #f
-	  (cond ((or (not (sequence? val)) 
-		     (empty? val))    "~S")
-		((vector? val)        "#(~{~A~| ~})")
-		((let? val)           "(inlet ~{'~A~| ~})")
-		((hash-table? val)    "(hash-table ~{'~A~| ~})")
-		((not (string? val))  "(~{~A~| ~})")
-		((byte-vector? val)   "#u8(~{~D~| ~})")
-		(else                 "\"~{~A~|~}\""))
-            val))
+  (let ((ctrl-str (cond ((or (not (sequence? val)) 
+			     (empty? val))    "~S")
+			((vector? val)        "#(~{~A~| ~})")
+			((let? val)           "(inlet ~{'~A~| ~})")
+			((hash-table? val)    "(hash-table ~{'~A~| ~})")
+			((not (string? val))  "(~{~A~| ~})")
+			((byte-vector? val)   "#u8(~{~D~| ~})")
+			(else                 "\"~{~A~|~}\""))))
+    (format #f ctrl-str val)))
 
 
 ;;; ----------------
@@ -1686,7 +1667,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 
 (define-macro* (rlambda args . body) ; lambda* but eval arg defaults in run-time env
   (let ((arg-names (map (lambda (arg) (if (pair? arg) (car arg) arg)) args))
-	(arg-defaults (map (lambda (arg) (if (pair? arg) `(,(car arg) (eval ,(cadr arg))) arg)) args)))
+	(arg-defaults (map (lambda (arg) (if (pair? arg) (list (car arg) (list 'eval (cadr arg))) arg)) args)))
     `(define-bacro* (,(gensym) ,@arg-defaults)
        `((lambda ,',arg-names ,'(begin ,@body)) ,,@arg-names))))
 
@@ -2077,12 +2058,12 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 
 (define* (make-directory-iterator name (recursive #t))
   (if (not (string? name))
-      (error "directory name should be a string: ~S" name)
+      (error 'wrong-type-arg "directory name should be a string: ~S" name)
       (make-iterator
        (with-let (sublet *libc* :name name :recursive recursive)
 	 (let ((dir (opendir name)))
 	   (if (equal? dir NULL)
-	       (error "can't open ~S: ~S" name (strerror (errno)))
+	       (error 'io-error "can't open ~S: ~S" name (strerror (errno)))
 	       (let ((iterator? #t))
 		 (define reader
 		   (let ((dirs ())
@@ -2130,3 +2111,19 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 					     (reader))
 					   (string-append dir-name "/" file)))))))))))))))))
 
+
+;;; --------------------------------------------------------------------------------
+
+(define null-environment
+  (let ((e #f))
+    (lambda ()
+      (or e
+	  (set! e (let ((lt (inlet)))
+		    (for-each (lambda (c)
+				(if (and (or (procedure? (cdr c))
+					     (macro? (cdr c)))
+					 (not (constant? (car c))))
+				    (varlet lt (car c) (symbol "[" (symbol->string (car c)) "]"))))
+			      (rootlet))
+		    (sublet lt)))))))
+
