@@ -3,7 +3,7 @@
 (define gl-file (open-output-file "gl.c"))
 
 (define-expansion (hey . args)
-  `(format gl-file ,@args))
+  (cons 'format (cons 'gl-file args)))
 
 (define (heyc arg)
   (display arg gl-file))
@@ -110,44 +110,45 @@
       (if (string=? type "XVisualInfo*")
 	  (copy "XVisualInfo")
 	  (let ((len (length type))
-		(val (string-copy type)))
+		(val (copy type)))
 	    (do ((i 0 (+ i 1)))
 		((= i len) val)
 	      (if (char=? (val i) #\*)
 		  (set! (val i) #\_)))))))
 
 (define* (parse-args args x)
-  (let ((data ())
-	(sp -1)
-	(type #f)
-	(len (length args)))
-    (if (string=? args "void")
-	()
-	(do ((i 0 (+ i 1)))
-	    ((= i len) (reverse data))
-	  (let ((ch (args i)))
-	    (when (or (char=? ch #\space)
-		      (= i (- len 1)))
-	      (if type
-		  (begin
-		    (let ((given-name (substring args (+ 1 sp) (if (= i (- len 1)) (+ i 1) i))))
-		      (case (given-name 0)
-			((#\@) (set! data (cons (list type (substring given-name 1) 'null) data)))
-			((#\#) (set! data (cons (list type (substring given-name 1) 'opt) data)))
-			((#\[)
-			 (set! data (cons (list type (substring given-name 1 (- (length given-name) 1)) given-name) data))
-			 (set! type (deref-type (list type))))
-			(else (set! data (cons (list type given-name) data)))))
-		    (if (eq? x 'x)
-			(if (not (member type x-types))
-			    (set! x-types (cons type x-types)))
-			(if (not (or (eq? x 'g)
-				     (member type types)))
-			    (set! types (cons type types))))
-		    (set! type #f))
-		  (if (> i (+ 1 sp))
-		      (set! type (substring args (+ 1 sp) i))))
-	      (set! sp i)))))))
+  (if (string=? args "void")
+      ()
+      (do ((data ())
+	   (sp -1)
+	   (type #f)
+	   (len (length args))
+	   (i 0 (+ i 1)))
+	  ((= i len) 
+	   (reverse data))
+	(let ((ch (args i)))
+	  (when (or (char=? ch #\space)
+		    (= i (- len 1)))
+	    (if type
+		(begin
+		  (let ((given-name (substring args (+ 1 sp) (if (= i (- len 1)) (+ i 1) i))))
+		    (case (given-name 0)
+		      ((#\@) (set! data (cons (list type (substring given-name 1) 'null) data)))
+		      ((#\#) (set! data (cons (list type (substring given-name 1) 'opt) data)))
+		      ((#\[)
+		       (set! data (cons (list type (substring given-name 1 (- (length given-name) 1)) given-name) data))
+		       (set! type (deref-type (list type))))
+		      (else (set! data (cons (list type given-name) data)))))
+		  (if (eq? x 'x)
+		      (if (not (member type x-types))
+			  (set! x-types (cons type x-types)))
+		      (if (not (or (eq? x 'g)
+				   (member type types)))
+			  (set! types (cons type types))))
+		  (set! type #f))
+		(if (> i (+ 1 sp))
+		    (set! type (substring args (+ 1 sp) i))))
+	    (set! sp i))))))
 
 (define (helpify name type args)
   (let ((initial (format #f "  #define H_~A \"~A ~A(" name type name)))
@@ -588,17 +589,20 @@
 	     (lambda (arg)
 	       (let ((argname (cadr arg))
 		     (argtype (car arg)))
-		 (if (not (ref-arg? arg))
-		     (if (null-arg? arg)
-			 (hey "  Xen_check_type(Xen_is_~A(~A) || Xen_is_false(~A), ~A, ~D, ~S, ~S);~%" 
-			      (no-stars argtype) argname argname argname ctr name argtype)
-			 (if (opt-arg? arg)
-			     (begin
-			       (hey "  if (!Xen_is_bound(~A)) ~A = Xen_false; ~%" argname argname)
-			       (hey "  else Xen_check_type(Xen_is_~A(~A), ~A, ~D, ~S, ~S);~%" 
-				    (no-stars argtype) argname argname ctr name argtype))
-			     (hey "  Xen_check_type(Xen_is_~A(~A), ~A, ~D, ~S, ~S);~%"
-				  (no-stars argtype) argname argname ctr name argtype))))
+		 (cond ((ref-arg? arg))
+
+		       ((null-arg? arg)
+			(hey "  Xen_check_type(Xen_is_~A(~A) || Xen_is_false(~A), ~A, ~D, ~S, ~S);~%" 
+			     (no-stars argtype) argname argname argname ctr name argtype))
+
+		       ((opt-arg? arg)
+			(hey "  if (!Xen_is_bound(~A)) ~A = Xen_false; ~%" argname argname)
+			(hey "  else Xen_check_type(Xen_is_~A(~A), ~A, ~D, ~S, ~S);~%" 
+			     (no-stars argtype) argname argname ctr name argtype))
+
+		       (else
+			(hey "  Xen_check_type(Xen_is_~A(~A), ~A, ~D, ~S, ~S);~%"
+			     (no-stars argtype) argname argname ctr name argtype)))
 		 (set! ctr (+ 1 ctr))))
 	     args)))
       (let ((using-result (and (> refargs 0)
@@ -655,7 +659,7 @@
 		    (hey "    return(result);~%")
 		    (hey "  }~%"))
 		  (begin
-		    (hey "  return(Xen_list_~D(" (+ refargs (if using-result 1 0)))
+		    (hey "  return(Xen_list_~D(" (if using-result (+ refargs 1) refargs))
 		    (if using-result (heyc "result"))
 		    (for-each 
 		     (lambda (arg)
@@ -736,14 +740,15 @@
 	       
 (define (make-signature fnc)
   (define (compress sig)
-    (if (and (pair? sig)
-	     (pair? (cdr sig))
-	     (not (and (eq? (car sig) 'pair?)
-		       (null? (cddr sig))))
-	     (eq? (car sig) (cadr sig)))
-	(compress (cdr sig))
-	sig))
-  (let ((sig (list (gtk-type->s7-type (cadr fnc)))))
+    (do ((sig sig (cdr sig)))
+	((not (and (pair? sig)
+		   (pair? (cdr sig))
+		   (not (and (eq? (car sig) 'pair?) (null? (cddr sig))))
+		   (eq? (car sig) (cadr sig))))
+	 sig)))
+  (let ((sig (list (if (positive? (ref-args (caddr fnc))) ; these are returned as cadr of list
+		       'pair?
+		       (gtk-type->s7-type (cadr fnc))))))
     (for-each
      (lambda (arg)
        (set! sig (cons (gtk-type->s7-type (car arg)) sig)))
@@ -755,10 +760,9 @@
   (for-each
    (lambda (f)
      (let ((sig (make-signature f)))
-       (if (pair? sig)
-	   (let ((count (signatures sig)))
-	     (if (not count)
-		 (set! (signatures sig) type))))))
+       (if (and (pair? sig)
+		(not (signatures sig)))
+	   (set! (signatures sig) type))))
    lst))
 
 (make-signatures funcs :gtk)
@@ -784,15 +788,27 @@
   (call-with-output-string
    (lambda (p)
      (display "pl_" p)
+     (display (case (car sig)
+		((integer?)    "i")
+		((boolean?)    "b")
+		((real?)       "d")
+		((string?)     "s")
+		((pair?)       "p")
+		((gtk_enum_t?) "g")
+		(else          "t"))
+	      p)
      (for-each
       (lambda (typ)
 	(display (case typ
-		   ((integer?) "i")
-		   ((boolean?) "b")
-		   ((real?) "r")
-		   (else "t"))
+		   ((integer?)    "i")
+		   ((boolean?)    "b")
+		   ((real?)       "r")
+		   ((string?)     "s")
+		   ((pair?)       "u") ; because we're stupidly using #f=null
+		   ((gtk_enum_t?) "g")
+		   (else          "t"))
 		 p))
-      sig))))
+      (cdr sig)))))
      
 (let ((ctr 0))
   (for-each
@@ -824,57 +840,36 @@
 (hey "  s_real = s7_make_symbol(s7, \"real?\");~%")
 (hey "  s_any = s7_t(s7);~%~%")
 
-(for-each
- (lambda (sigc)
-   (if (eq? (cdr sigc) :gtk)
-       (let ((sig (car sigc)))
-	 (hey "  ")
-	 (hey (sig-name sig))
-	 (hey " = s7_make_circular_signature(s7, ")
-	 (let ((len (length sig)))
-	   (hey (number->string (- len 1)))
-	   (hey ", ")
-	   (hey (number->string len))
-	   (hey ", ")
-	   (do ((i 0 (+ i 1))
-		(s sig (cdr s)))
-	       ((= i len))
-	     (let ((typ (car s)))
-	       (hey (case typ
-		      ((integer?) "s_integer")
-		      ((boolean?) "s_boolean")
-		      ((real?) "s_real")
-		      (else "s_any"))))
-	     (if (< i (- len 1)) (hey ", "))))
-	 (hey ");~%"))))
- signatures)
-(hey "~%")
-(hey "#if USE_MOTIF~%")
-(for-each
- (lambda (sigc)
-   (if (eq? (cdr sigc) :motif)
-       (let ((sig (car sigc)))
-	 (hey "  ")
-	 (hey (sig-name sig))
-	 (hey " = s7_make_circular_signature(s7, ")
-	 (let ((len (length sig)))
-	   (hey (number->string (- len 1)))
-	   (hey ", ")
-	   (hey (number->string len))
-	   (hey ", ")
-	   (do ((i 0 (+ i 1))
-		(s sig (cdr s)))
-	       ((= i len))
-	     (let ((typ (car s)))
-	       (hey (case typ
-		      ((integer?) "s_integer")
-		      ((boolean?) "s_boolean")
-		      ((real?) "s_real")
-		      (else "s_any"))))
-	     (if (< i (- len 1)) (hey ", "))))
-	 (hey ");~%"))))
- signatures)
-(hey "#endif~%")
+(let ((sigout (lambda (gui)
+		(for-each
+		 (lambda (sigc)
+		   (if (eq? (cdr sigc) gui)
+		       (let ((sig (car sigc)))
+			 (hey "  ")
+			 (hey (sig-name sig))
+			 (hey " = s7_make_circular_signature(s7, ")
+			 (let ((len (length sig)))
+			   (hey (number->string (- len 1)))
+			   (hey ", ")
+			   (hey (number->string len))
+			   (hey ", ")
+			   (do ((i 0 (+ i 1))
+				(s sig (cdr s)))
+			       ((= i len))
+			     (let ((typ (car s)))
+			       (hey (case typ
+				      ((integer?) "s_integer")
+				      ((boolean?) "s_boolean")
+				      ((real?) "s_real")
+				      (else "s_any"))))
+			     (if (< i (- len 1)) (hey ", "))))
+			 (hey ");~%"))))
+		 signatures))))
+  (sigout :gtk)
+  (hey "~%")
+  (hey "#if USE_MOTIF~%")
+  (sigout :motif)
+  (hey "#endif~%"))
 (hey "#endif~%~%")
 
 (hey "#if HAVE_SCHEME~%")
