@@ -1,38 +1,42 @@
 ;;; try each s7test test macro (using repl, not snd)
 
+(define aux-counter 0)
 (system "make-repl")
 
 (for-each
  (lambda (test-case)
-   (call-with-output-file "t101-aux.scm"
-     (lambda (p)
-       (format p "(define-macro (test tst expected) ~A)~%(load \"s7test.scm\")~%(exit)~%" test-case)))
-   (format *stderr* "test: ~S~%" test-case)
-   (system "./repl t101-aux.scm"))
+   (let ((aux-file (format #f "t101-aux-~D.scm" (set! aux-counter (+ aux-counter 1)))))
+     (call-with-output-file aux-file
+       (lambda (p)
+	 (format p "(define-macro (test tst expected) ~A)~%(load \"s7test.scm\")~%(exit)~%" test-case)))
+     (format *stderr* "test: ~S~%" test-case)
+     (system (string-append "./repl " aux-file))))
  (list 
-   "`(ok? ',tst (lambda () (eval ',tst)) ,expected)"
-   "`(ok? ',tst (lambda () ,tst) ,expected)"
-   "`(ok? ',tst (let () (define (_s7_) ,tst)) ,expected)"
-   "`(ok? ',tst (lambda () (let ((_s7_ #f)) (set! _s7_ ,tst))) ,expected)"
-   "`(ok? ',tst (lambda () (let ((_s7_ ,tst)) _s7_)) ,expected)"
-   "`(ok? ',tst (catch #t (lambda () (lambda* ((_a_ ,tst)) _a_)) (lambda any (lambda () 'error))) ,expected)"
-   "`(ok? ',tst (lambda () (do ((_a_ ,tst)) (#t _a_))) ,expected)"
-   "`(ok? ',tst (lambda () (do ((__i__ 0 (+ __i__ 1))) ((= __i__ 1) ,expected) ,tst)) ,expected)"
-   "`(ok? ',tst (lambda () (define ($f$) (let (($v$ (vector #f))) (do (($i$ 0 (+ $i$ 1))) ((= $i$ 1) ($v$ 0)) (vector-set! $v$ 0 ,tst)))) ($f$)) ,expected)"
-   "`(ok? ',tst (lambda () (define ($f$) (let (($v$ #f)) (do (($i$ 0 (+ $i$ 1))) ((= $i$ 1) $v$) (set! $v$ ,tst)))) ($f$)) ,expected)"
-   "`(ok? ',tst (lambda () (define ($f$) (let ((x (map (lambda (a) ,tst) '(0)))) (car x))) ($f$)) ,expected)"
-   "`(ok? ',tst (lambda () (call-with-exit (lambda (_a_) (_a_ ,tst)))) ,expected)"
-   "`(ok? ',tst (lambda () (call/cc (lambda (_a_) (_a_ ,tst)))) ,expected)"
-   "`(ok? ',tst (lambda () (values ,tst)) ,expected)"
-   "`(ok? ',tst (lambda () ((lambda (a b) b) (values #f ,tst))) ,expected)"
-   "`(ok? ',tst (lambda () (define (_s7_ _a_) _a_) (_s7_ ,tst)) ,expected)"
-   "`(ok? ',tst (lambda () (let ((___x #f)) (set! ___x ,tst))) ,expected)"
-   "`(ok? ',tst (lambda () (let ((___x #(#f))) (set! (___x 0) ,tst))) ,expected)"
-   "`(ok? ',tst (lambda () (let ((___x #(#f))) (vector-set! ___x 0 ,tst))) ,expected)"
-   "`(ok? ',tst (lambda () (define* (_s7_ (_a_ #f)) (or _a_)) (_s7_ ,tst)) ,expected)"
-   "`(ok? ',tst (lambda () (dynamic-wind (lambda () #f) (lambda () ,tst) (lambda () #f))) ,expected)"
-   "({list} 'ok? ({list} quote tst) ({list} lambda () tst) expected)"
-   ))
+  "`(ok? ',tst (lambda () (eval ',tst)) ,expected)"
+  "`(ok? ',tst (lambda () ,tst) ,expected)"
+  "`(ok? ',tst (let () (define (_s7_) ,tst)) ,expected)"
+  "`(ok? ',tst (lambda () (let ((_s7_ #f)) (set! _s7_ ,tst))) ,expected)"
+  "`(ok? ',tst (lambda () (let ((_s7_ ,tst)) _s7_)) ,expected)"
+  "`(ok? ',tst (catch #t (lambda () (lambda* ((_a_ ,tst)) _a_)) (lambda any (lambda () 'error))) ,expected)"
+  "`(ok? ',tst (lambda () (do ((_a_ ,tst)) (#t _a_))) ,expected)"
+  "`(ok? ',tst (lambda () (do ((__i__ 0 (+ __i__ 1))) ((= __i__ 1) ,expected) ,tst)) ,expected)"
+  "`(ok? ',tst (lambda () (define ($f$) (let (($v$ (vector #f))) (do (($i$ 0 (+ $i$ 1))) ((= $i$ 1) ($v$ 0)) (vector-set! $v$ 0 ,tst)))) ($f$)) ,expected)"
+  "`(ok? ',tst (lambda () (define ($f$) (let (($v$ #f)) (do (($i$ 0 (+ $i$ 1))) ((= $i$ 1) $v$) (set! $v$ ,tst)))) ($f$)) ,expected)"
+  "`(ok? ',tst (lambda () (define ($f$) (let ((x (map (lambda (a) ,tst) '(0)))) (car x))) ($f$)) ,expected)"
+  "`(ok? ',tst (lambda () (call-with-exit (lambda (_a_) (_a_ ,tst)))) ,expected)"
+  "`(ok? ',tst (lambda () (call/cc (lambda (_a_) (_a_ ,tst)))) ,expected)"
+  "`(ok? ',tst (lambda () (values ,tst)) ,expected)"
+  "`(ok? ',tst (lambda () ((lambda (a b) b) (values #f ,tst))) ,expected)"
+  "`(ok? ',tst (lambda () (define (_s7_ _a_) _a_) (_s7_ ,tst)) ,expected)"
+  "`(ok? ',tst (lambda () (let ((___x #f)) (set! ___x ,tst))) ,expected)"
+  "`(ok? ',tst (lambda () (let ((___x #(#f))) (set! (___x 0) ,tst))) ,expected)"
+  "`(ok? ',tst (lambda () (let ((___x #(#f))) (vector-set! ___x 0 ,tst))) ,expected)"
+  "`(ok? ',tst (lambda () (define* (_s7_ (_a_ #f)) (or _a_)) (_s7_ ,tst)) ,expected)"
+  "`(ok? ',tst (lambda () (dynamic-wind (lambda () #f) (lambda () ,tst) (lambda () #f))) ,expected)"
+  "`(ok? ',tst (lambda () (caadr (catch 'receive (lambda () (throw 'receive ,tst)) (lambda any any)))) ,expected)"
+  "`(ok? ',tst (lambda () (stacktrace (- (random 100) 50) (- (random 100) 50) (- (random 100) 50) (- (random 100) 50) (> (random 100) 50)) ,tst) ,expected)"
+  "({list} 'ok? ({list} quote tst) ({list} lambda () tst) expected)"
+  ))
 
 (format *stderr* "~NC ffitest ~NC~%" 20 #\- 20 #\-)
 (if (provided? 'linux)
@@ -100,9 +104,6 @@
 (format *stderr* "~NC makegl ~NC~%" 20 #\- 20 #\-)
 (system "./snd makegl.scm")
 
-(format *stderr* "~NC lg ~NC~%" 20 #\- 20 #\-)
-(system "./repl lg.scm")
-
 (format *stderr* "~NC tgen ~NC~%" 20 #\- 20 #\-)
 (system "./snd tgen.scm")
 
@@ -115,4 +116,7 @@
 (format *stderr* "~NC bench ~NC~%" 20 #\- 20 #\-)
 (system "(cd /home/bil/test/bench/src ; /home/bil/cl/snd test-all.scm)")
 
+(format *stderr* "~NC lg ~NC~%" 20 #\- 20 #\-)
+(system "./repl lg.scm")
+
 (exit)
