@@ -62,24 +62,24 @@
 		   (let ((len (length line)))
 		     (set! line-number (+ line-number 1))
 		     (if (> len 8)
-			 (let ((start 0))
-			   (do ((i 1 (+ i 1)))
-			       ((>= i len))
-			     (let ((chr (line i)))
-			       (if (or (char-whitespace? chr)
-				       (char=? chr #\)))
-				   (let* ((name (substring line (+ 1 start) i))
-					  (name-len (length name)))
-				     (if (and (or (and (> name-len 4)
-						       (member (substring name 0 4) '("gtk_" "gdk_") string-ci=?))
-						  (and (> name-len 6)
-						       (member (substring name 0 6) '("pango_" "cairo_") string-ci=?)))
-					      (not (defined? (string->symbol name) *gtk*)))
-					 (format () "~A (~A[~D]) is not defined~%" name filename line-number))))
-			       (if (not (or (char=? chr #\_)
-					    (char-alphabetic? chr)
-					    (char-numeric? chr)))
-				   (set! start i))))))
+			 (do ((start 0)
+			      (i 1 (+ i 1)))
+			     ((>= i len))
+			   (let ((chr (line i)))
+			     (if (or (char-whitespace? chr)
+				     (char=? chr #\)))
+				 (let* ((name (substring line (+ 1 start) i))
+					(name-len (length name)))
+				   (if (and (or (and (> name-len 4)
+						     (member (substring name 0 4) '("gtk_" "gdk_") string-ci=?))
+						(and (> name-len 6)
+						     (member (substring name 0 6) '("pango_" "cairo_") string-ci=?)))
+					    (not (defined? (string->symbol name) *gtk*)))
+				       (format () "~A (~A[~D]) is not defined~%" name filename line-number))))
+			     (if (not (or (char=? chr #\_)
+					  (char-alphabetic? chr)
+					  (char-numeric? chr)))
+				 (set! start i)))))
 		     (loop (read-line file #t)))))))))
      
 					;   (if (string=? (substring filename (- (length filename) 3)) "scm")
