@@ -61,7 +61,7 @@
 		 ,@(cdr body))))
 	   ,@(if *definstrument-hook*
 		 (list (*definstrument-hook* name targs))
-		 (list)))
+		 ()))
 	`(begin 
 	   (define* (,name ,@targs)
 	     (if *clm-notehook*
@@ -69,7 +69,7 @@
 	     ,@body)
 	   ,@(if *definstrument-hook*
 		 (list (*definstrument-hook* name targs))
-		 (list))))))
+		 ())))))
 
      
 
@@ -245,11 +245,11 @@
 			(if output-to-file
 			    (if to-snd
 				(maxamp snd-output #t) ; this is a list of chan maxs '(.1 .2)
-				(let ((lst (mus-sound-maxamp output-1)))
-				  (do ((i 0 (+ i 2)))
-				      ((>= i (length lst)))
-				    (set! (lst i) (/ (lst i) *clm-srate*)))
-				  lst))
+				(do ((lst (mus-sound-maxamp output-1))
+				     (i 0 (+ i 2)))
+				      ((>= i (length lst))
+				       lst)
+				  (set! (lst i) (/ (lst i) *clm-srate*))))
 			    (if (vector? output-1)
 				(list (maxamp output-1))
 				'(0.0)))
@@ -282,11 +282,10 @@
 		 (scaled-to
 		  (let ((pk (maxamp output-1)))
 		    (if (> pk 0.0)
-			(let ((scl (/ scaled-to pk)))
-			  (do ((i 0 (+ i 1)))
-			      ((= i (length output-1)))
-			    (set! (output-1 i) (* scl (output-1 i))))))))
-		 
+			(do ((scl (/ scaled-to pk))
+			     (i 0 (+ i 1)))
+			    ((= i (length output-1)))
+			  (set! (output-1 i) (* scl (output-1 i)))))))
 		 (else
 		  (do ((i 0 (+ i 1)))
 		      ((= i (length output-1)))
@@ -733,7 +732,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 				 (name 1)))
 		 (octave (if octave-char (- (char->integer octave-char) (char->integer #\0)) last-octave))
 		 (base-pitch (let ((base (modulo (- (+ (char->integer (name 0)) 5) (char->integer #\a)) 7)) ; c-based (diatonic) octaves	   
-				   (sign (if (not sign-char) 0 (if (char=? sign-char #\f) -1 1))))
+				   (sign (case sign-char ((#f) 0) ((#\f) -1) (else 1))))
 			       (+ sign (case base ((0) 0) ((1) 2) ((2) 4) ((3) 5) ((4) 7) ((5) 9) ((6) 11)))))
 		 (et-pitch (+ base-pitch (* 12 octave))))
 	    (set! last-octave octave)
