@@ -61,11 +61,9 @@
   (define (xe-mouse-press drawer xx yy)
 
     (define (xe-envelope-position x cur-env)
-      (let search-point ((e cur-env)
-			 (pos 0))
-	(if (= (car e) x)
-	    pos
-	    (search-point (cddr e) (+ pos 2)))))
+      (do ((e cur-env (cddr e)) 
+	   (pos 0 (+ pos 2))) 
+	  ((= (car e) x) pos)))
 
     (define (xe-on-dot? x y cur-env pos)
       (let ((xe-mouse-radius .03))
@@ -102,14 +100,12 @@
   (define (xe-mouse-drag drawer xx yy)
 
     (define (xe-edit-envelope-point pos x y cur-env)
-      (let ((new-env ()))
-	(let search-point ((e cur-env)
-			   (npos 0))
-	  (if (= npos pos)
-	      (append new-env (list x y) (cddr e))
-	      (begin
-		(set! new-env (append new-env (list (car e) (cadr e))))
-		(search-point (cddr e) (+ npos 2)))))))
+      (do ((new-env ())
+	   (e cur-env (cddr e))
+	   (npos 0 (+ npos 2)))
+	  ((= npos pos) 
+	   (append new-env (list x y) (cddr e)))
+	(set! new-env (append new-env (list (car e) (cadr e))))))
     
     ;; point exists, needs to be edited with check for various bounds
     (let* ((cur-env (xe-envelope drawer))
@@ -250,9 +246,9 @@
 					    (g_signal_lookup "configure_event" (G_OBJECT_TYPE (G_OBJECT drawer)))
 					    0 gf #f))
 	  (let ((gf (g_cclosure_new (lambda (w e d) 
-				      (let ((coords (gdk_event_get_coords (GDK_EVENT e))))
+				      (let ((coords (cdr (gdk_event_get_coords (GDK_EVENT e)))))
 					(set! dragging #t)
-					(xe-mouse-press editor (cadr coords) (caddr coords)))
+					(xe-mouse-press editor (car coords) (cadr coords)))
 				      #f)
 				    #f #f)))
 	    (g_signal_connect_closure_by_id (GPOINTER drawer)
@@ -268,8 +264,8 @@
 					    0 gf #f))
 	  (let ((gf (g_cclosure_new (lambda (w e d) 
 				      (if dragging
-					  (let ((coords (gdk_event_get_coords (GDK_EVENT e))))
-					    (xe-mouse-drag editor (cadr coords) (caddr coords))))
+					  (let ((coords (cdr (gdk_event_get_coords (GDK_EVENT e)))))
+					    (xe-mouse-drag editor (car coords) (cadr coords))))
 				      #f)
 				    #f #f)))
 	    (g_signal_connect_closure_by_id (GPOINTER drawer)
@@ -296,7 +292,7 @@
   (let* ((cur-env (xe-envelope drawer))
 	 (widget (drawer 1))
 	 (dpy (and (provided? 'snd-motif) ((*motif* 'XtDisplay) widget)))
-	 (wn (if (provided? 'snd-motif) ((*motif* 'XtWindow) widget) ((*gtk* 'gtk_widget_get_window) widget)))
+	 (wn ((if (provided? 'snd-motif) (*motif* 'XtWindow) (*gtk* 'gtk_widget_get_window)) widget))
 	 (ax-pix (drawer 2))
 	 (ax-inf (drawer 3))
 	 (gc (car (drawer 4)))
@@ -305,9 +301,7 @@
 	 (get_realized (if (provided? 'snd-gtk) (*gtk* 'gtk_widget_get_realized))))
     (when (and (list? ax-pix)
 	       (list? cur-env)
-	       (if (provided? 'snd-motif)
-		   ((*motif* 'XtIsManaged) widget)
-		   (get_realized widget)))
+	       ((if (provided? 'snd-motif) (*motif* 'XtIsManaged) get_realized) widget))
       (let ((py0 (ax-pix 1))
 	    (py1 (ax-pix 3))
 	    (ix0 (ax-inf 0))
@@ -355,7 +349,7 @@
 		    (set! lx cx)
 		    (set! ly cy))))
 	      ;; *gtk* 
-	      (let ((cr ((*gtk* 'gdk_cairo_create) ((*gtk* 'GDK_WINDOW) wn))))
+	      (let ((cr ((*gtk* 'make_cairo) ((*gtk* 'GDK_WINDOW) wn))))
 		
 		(let ((size (widget-size ((*gtk* 'GTK_WIDGET) widget))))
 		  ((*gtk* 'cairo_push_group) cr)
@@ -384,5 +378,5 @@
 		    (set! ly cy)))
 		((*gtk* 'cairo_pop_group_to_source) cr)
 		((*gtk* 'cairo_paint) cr)
-		((*gtk* 'cairo_destroy) cr))))))))
+		((*gtk* 'free_cairo) cr))))))))
 
